@@ -24,9 +24,7 @@
 ----------------------------------------------------------------------*/
 
 #include "glpapi.h"
-#include "glpk.h"
 #include "glpgmp.h"
-#include "glplib.h"
 #include "glpmpl.h"
 #define print xprint1
 #define fault old_fault
@@ -81,10 +79,8 @@ static int method = 0;
    1 - interior point
    2 - branch-and-bound */
 
-#if 1 /* 12/XI-2006 */
 static int exact = 0;
 /* if this flag is set, use lpx_exact rather than lpx_simplex */
-#endif
 
 #if 0 /* 12/XI-2006 */
 static int primal = 0;
@@ -142,6 +138,12 @@ static char *log_file = NULL;
 static char *newname = NULL;
 /* new name which has to be assigned to the problem */
 
+static bf_type = 1;
+/* which LP basis factorization should be used:
+   1 - LP basis factorization option:
+   2 - LU + Schur complement + Bartels-Golub update
+   3 - LU + Schur complement + Givens rotation update */
+
 static int basis = 1;
 /* which initial basis should be used:
    0 - standard initial basis
@@ -162,11 +164,9 @@ static int presol = 1;
 /* if this flag is set, the solver uses the LP presolver; otherwise the
    LP presolver is not used */
 
-#if 1 /* 08/XI-2006 */
 static int xcheck = 0;
 /* if this flag is set, the solver checks the final basis using exact
    (bignum) arithmetic */
-#endif
 
 static int nomip = 0;
 /* if this flag is set, the solver considers all integer variables as
@@ -274,6 +274,16 @@ static void display_help(char *my_name)
          "t");
       print("   -v, --version     display program version and exit");
       print("");
+      print("LP basis factorization option:");
+      print("   --luf             LU + Forrest-Tomlin update");
+      print("                     (faster, less stable; default)");
+      print("   --cbg             LU + Schur complement + Bartels-Golub"
+         " update");
+      print("                     (slower, more stable)");
+      print("   --cgr             LU + Schur complement + Givens rotati"
+         "on update");
+      print("                     (slower, more stable)");
+      print("");
       print("Options specific to simplex method:");
       print("   --std             use standard initial basis of all sla"
          "cks");
@@ -292,14 +302,10 @@ static void display_help(char *my_name)
       print("   --presol          use presolver (default; assumes --sca"
          "le and --adv)");
       print("   --nopresol        do not use presolver");
-#if 1 /* 12/XI-2006 */
       print("   --exact           use simplex method based on exact ari"
          "thmetic");
-#endif
-#if 1 /* 08/XI-2006 */
       print("   --xcheck          check final basis using exact arithme"
          "tic");
-#endif
       print("   --wbas filename   write final basis to filename in MPS "
          "format");
       print("");
@@ -354,7 +360,7 @@ static void display_help(char *my_name)
 -- by the GNU Coding Standards. */
 
 static void display_version(void)
-{     print("GLPSOL---GLPK LP/MIP Solver, Version %s", glp_version());
+{     print("GLPSOL---GLPK LP/MIP Solver, Version %s", lib_version());
       print("");
       print("Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makh"
          "orin,");
@@ -567,6 +573,12 @@ static void parse_cmdline(int argc, char *argv[])
             display_help(argv[0]);
          else if (p("-v") || p("--version"))
             display_version();
+         else if (p("--luf"))
+            bf_type = 1;
+         else if (p("--cbg"))
+            bf_type = 2;
+         else if (p("--cgr"))
+            bf_type = 3;
 #if 0 /* 12/XI-2006 */
          else if (p("--primal"))
             primal = 1;
@@ -601,14 +613,10 @@ static void parse_cmdline(int argc, char *argv[])
             presol = 1;
          else if (p("--nopresol"))
             presol = 0;
-#if 1 /* 12/XI-2006 */
          else if (p("--exact"))
             exact = 1, presol = 0;
-#endif
-#if 1 /* 08/XI-2006 */
          else if (p("--xcheck"))
             xcheck = 1;
-#endif
          else if (p("--wbas"))
          {  k++;
             if (k == argc || argv[k][0] == '\0' || argv[k][0] == '-')
@@ -682,14 +690,8 @@ int main(int argc, char *argv[])
       /* parse command line parameters */
       parse_cmdline(argc, argv);
       /* set available memory limit */
-#if 0
-      if (memlim >= 0 && memlim < INT_MAX / (1024 * 1024))
-         lib_env_ptr()->mem_limit = (1024 * 1024) * memlim;
-#else
       if (memlim >= 0)
-         lib_link_env()->mem_limit =
-            ulmul(ulset(0, 1024 * 1024), ulset(0, memlim));
-#endif
+         lib_mem_limit(ulmul(ulset(0, 1048576), ulset(0, memlim)));
       /* remove all output files specified in the command line */
       if (display != NULL) remove(display);
       if (out_bas != NULL) remove(out_bas);
@@ -752,16 +754,6 @@ err:        {  print("Model processing error");
             /* extract problem instance */
             lp = lpx_extract_prob(mpl);
             xassert(lp != NULL);
-#if 0
-            if (lpx_get_num_rows(lp) == 0)
-            {  print("Problem has no rows");
-               exit(EXIT_FAILURE);
-            }
-            if (lpx_get_num_cols(lp) == 0)
-            {  print("Problem has no columns");
-               exit(EXIT_FAILURE);
-            }
-#endif
             break;
          case 3:
             lp = lpx_read_prob(in_file);
@@ -872,6 +864,7 @@ nobs:    ;
       }
       /* set some control parameters, which might be changed in the
          command line */
+      lpx_set_int_parm(lp, LPX_K_BFTYPE, bf_type);
       lpx_set_int_parm(lp, LPX_K_PRICE, price);
       if (!relax) lpx_set_real_parm(lp, LPX_K_RELAX, 0.0);
       lpx_set_int_parm(lp, LPX_K_PRESOL, presol);
@@ -886,7 +879,6 @@ nobs:    ;
       {  case 0:
             if (nomip || lpx_get_class(lp) == LPX_LP)
             {  ret = (!exact ? lpx_simplex(lp) : lpx_exact(lp));
-#if 1 /* 08/XI-2006 */
                if (xcheck)
                {  if (!presol || ret == LPX_E_OK)
                      lpx_exact(lp);
@@ -894,7 +886,6 @@ nobs:    ;
                      print("If you need checking final basis for non-op"
                         "timal solution, use --nopresol");
                }
-#endif
                if (presol && ret != LPX_E_OK && (out_bas != NULL ||
                   out_sol != NULL))
                   print("If you need actual output for non-optimal solu"
@@ -926,18 +917,13 @@ nobs:    ;
       }
       /* display statistics */
       print("Time used:   %.1f secs", xdifftime(xtime(), start));
-#if 0
-      print("Memory used: %.1fM (%d bytes)",
-         (double)lib_link_env()->mem_tpeak / (double)(1024 * 1024),
-         lib_link_env()->mem_tpeak);
-#else
-      {  double tpeak;
-         tpeak = (double)lib_link_env()->mem_tpeak.hi;
-         tpeak *= 4294967296.0;
-         tpeak += (double)lib_link_env()->mem_tpeak.lo;
-         print("Memory used: %.1fM", tpeak / (double)(1024 * 1024));
+      {  ulong_t tpeak;
+         char buf[50];
+         lib_mem_usage(NULL, NULL, NULL, &tpeak);
+         print("Memory used: %.1f Mb (%s bytes)",
+            (4294967296.0 * tpeak.hi + tpeak.lo) / 1048576.0,
+            ultoa(tpeak, buf, 10));
       }
-#endif
       if (mpl != NULL && mpl_has_solve_stmt(mpl))
       {  int n, j, round;
          /* store the solution to the translator database */
@@ -1015,21 +1001,17 @@ skip: /* delete the problem object */
       lpx_delete_prob(lp);
       /* if the translator database exists, destroy it */
       if (mpl != NULL) mpl_terminate(mpl);
-#if 1 /* 08/XI-2006 */
       xassert(gmp_pool_count() == 0);
       gmp_free_mem();
-#endif
-
+      /* close the hardcopy file */
       if (log_file != NULL) lib_close_log();
-
       /* check that no memory blocks are still allocated */
-#if 0
-      xassert(lib_link_env()->mem_total == 0);
-      xassert(lib_link_env()->mem_count == 0);
-#else
-      xassert(ulcmp(lib_link_env()->mem_total, ulset(0, 0)) == 0);
-      xassert(lib_link_env()->mem_count == 0);
-#endif
+      {  int count;
+         ulong_t total;
+         lib_mem_usage(&count, NULL, &total, NULL);
+         xassert(count == 0);
+         xassert(total.lo == 0 && total.hi == 0);
+      }
       /* free the library environment */
       lib_free_env();
       /* return to the control program */
