@@ -24,8 +24,6 @@
 ----------------------------------------------------------------------*/
 
 #include "glpapi.h"
-#include "glpk.h"
-#include "glplib.h"
 #include "glpios.h"
 #include "glptsp.h"
 #define print xprint1
@@ -159,11 +157,8 @@ struct EDGE
       /* number of another node incident to corresponding edge */
 };
 
-static DMP *subtour_pool;
-/* memory pool for SUBTOUR entries */
-
-static DMP *edge_pool;
-/* memory pool for EDGE entries */
+static DMP *pool;
+/* memory pool for SUBTOUR and EDGE entries */
 
 /*----------------------------------------------------------------------
 -- greedy_tour - find salesman's tour using greedy heuristic.
@@ -238,7 +233,7 @@ static void initialize(IOS *ios)
          if (i > j) temp = i, i = j, j = temp;
          sprintf(name, "%d-%d*", i, j);
          ios_set_col_name(ios, k, name);
-         edge = dmp_get_atom(edge_pool);
+         edge = dmp_get_atom(pool, sizeof(EDGE));
          edge->i = i, edge->j = j;
          ios_set_col_attr(ios, k, EDGE_MARK, edge);
          ios_set_col_kind(ios, k, IOS_INT);
@@ -357,7 +352,7 @@ skip:       ;
          k = ios_get_num_cols(ios);
          sprintf(name, "%d-%d", i, j);
          ios_set_col_name(ios, k, name);
-         edge = dmp_get_atom(edge_pool);
+         edge = dmp_get_atom(pool, sizeof(EDGE));
          edge->i = i, edge->j = j;
          ios_set_col_attr(ios, k, EDGE_MARK, edge);
          ios_set_col_kind(ios, k, IOS_INT);
@@ -844,7 +839,7 @@ static void gen_subt_row(IOS *ios)
          head = NULL;
          for (i = 1; i <= nn; i++)
          {  if (cut[i])
-            {  subt = dmp_get_atom(subtour_pool);
+            {  subt = dmp_get_atom(pool, sizeof(SUBTOUR));
                subt->i = i;
                subt->next = head;
                head = subt;
@@ -1004,7 +999,7 @@ static void appl_proc(IOS *ios, void *info)
                      while (head != NULL)
                      {  subt = head;
                         head = subt->next;
-                        dmp_free_atom(subtour_pool, subt);
+                        dmp_free_atom(pool, subt, sizeof(SUBTOUR));
                      }
                   }
                   break;
@@ -1020,7 +1015,7 @@ static void appl_proc(IOS *ios, void *info)
                   /* it is edge variable */
                   {  EDGE *edge;
                      edge = ios_get_col_link(ios, 0);
-                     dmp_free_atom(edge_pool, edge);
+                     dmp_free_atom(pool, edge, sizeof(EDGE));
                   }
                   break;
                default:
@@ -1098,26 +1093,22 @@ int main(int argc, char *argv[])
          exit(EXIT_FAILURE);
       }
       nodes = tsp->dimension;
-      /* create dynamic memory pools */
-      edge_pool = dmp_create_pool(sizeof(EDGE));
-      subtour_pool = dmp_create_pool(sizeof(SUBTOUR));
+      /* create dynamic memory pool */
+      pool = dmp_create_pool();
       /* call the IOS driver */
       ios_driver(appl_proc, NULL);
-      /* delete dynamic memory pools */
-      xassert(edge_pool->count == 0);
-      dmp_delete_pool(edge_pool);
-      xassert(subtour_pool->count == 0);
-      dmp_delete_pool(subtour_pool);
+      /* delete dynamic memory pool */
+      xassert(dmp_in_use(pool).lo == 0);
+      dmp_delete_pool(pool);
       /* delete problem instance */
       tsp_free_data(tsp);
-      /* check that no memory blocks have been lost */
-#if 0
-      xassert(lib_env_ptr()->mem_total == 0);
-      xassert(lib_env_ptr()->mem_count == 0);
-#else
-      xassert(ulcmp(lib_link_env()->mem_total, ulset(0, 0)) == 0);
-      xassert(lib_link_env()->mem_count == 0);
-#endif
+      /* check that no memory blocks are still allocated */
+      {  int count;
+         ulong_t total;
+         lib_mem_usage(&count, NULL, &total, NULL);
+         xassert(count == 0);
+         xassert(total.lo == 0 && total.hi == 0);
+      }
       /* return to the control program */
       return 0;
 }
