@@ -1,203 +1,56 @@
 /* glpapi.h (application program interface) */
 
-/*----------------------------------------------------------------------
--- This code is part of GNU Linear Programming Kit (GLPK).
---
--- Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
--- Department for Applied Informatics, Moscow Aviation Institute,
--- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
---
--- GLPK is free software; you can redistribute it and/or modify it
--- under the terms of the GNU General Public License as published by
--- the Free Software Foundation; either version 2, or (at your option)
--- any later version.
---
--- GLPK is distributed in the hope that it will be useful, but WITHOUT
--- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
--- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
--- License for more details.
---
--- You should have received a copy of the GNU General Public License
--- along with GLPK; see the file COPYING. If not, write to the Free
--- Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
--- 02110-1301, USA.
-----------------------------------------------------------------------*/
+/***********************************************************************
+*  This code is part of GNU Linear Programming Kit (GLPK).
+*
+*  Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
+*  Department for Applied Informatics, Moscow Aviation Institute,
+*  Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
+*
+*  GLPK is free software; you can redistribute it and/or modify it
+*  under the terms of the GNU General Public License as published by
+*  the Free Software Foundation; either version 2, or (at your option)
+*  any later version.
+*
+*  GLPK is distributed in the hope that it will be useful, but WITHOUT
+*  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+*  or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
+*  License for more details.
+*
+*  You should have received a copy of the GNU General Public License
+*  along with GLPK; see the file COPYING. If not, write to the Free
+*  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+*  02110-1301, USA.
+***********************************************************************/
 
 #ifndef _GLPAPI_H
 #define _GLPAPI_H
 
-#include "glpavl.h"
 #include "glpbfi.h"
-#include "glpstr.h"
 
-/*----------------------------------------------------------------------
--- The structure LPX is an LP/MIP problem object, which corresponds to
--- the following problem statement:
---
---    minimize (or maximize)
---
---       Z = c[1]*x[m+1] + c[2]*x[m+2] + ... + c[n]*x[m+n] + c[0]    (1)
---
---    subject to linear constraints
---
---       x[1] = a[1,1]*x[m+1] + a[1,2]*x[m+1] + ... + a[1,n]*x[m+n]
---       x[2] = a[2,1]*x[m+1] + a[2,2]*x[m+1] + ... + a[2,n]*x[m+n]  (2)
---                . . . . . .
---       x[m] = a[m,1]*x[m+1] + a[m,2]*x[m+1] + ... + a[m,n]*x[m+n]
---
---    and bounds of variables
---
---         l[1] <= x[1]   <= u[1]
---         l[2] <= x[2]   <= u[2]                                    (3)
---             . . . . . .
---       l[m+n] <= x[m+n] <= u[m+n]
---
--- where:
--- x[1], ..., x[m]      - rows (auxiliary variables);
--- x[m+1], ..., x[m+n]  - columns (structural variables);
--- Z                    - objective function;
--- c[1], ..., c[n]      - coefficients of the objective function;
--- c[0]                 - constant term of the objective function;
--- a[1,1], ..., a[m,n]  - constraint coefficients;
--- l[1], ..., l[m+n]    - lower bounds of variables;
--- u[1], ..., u[m+n]    - upper bounds of variables.
---
--- Using vector-matrix notations the LP problem (1)-(3) can be written
--- as follows:
---
---    minimize (or maximize)
---
---       Z = c * x + c[0]                                            (4)
---
---    subject to linear constraints
---
---       xR = A * xS                                                 (5)
---
---    and bounds of variables
---
---       l <= x <= u                                                 (6)
---
--- where:
--- xR                   - vector of auxiliary variables;
--- xS                   - vector of structural variables;
--- x = (xR, xS)         - vector of all variables;
--- c                    - vector of objective coefficients;
--- A                    - constraint matrix (has m rows and n columns);
--- l                    - vector of lower bounds of variables;
--- u                    - vector of upper bounds of variables.
---
--- The system of constraints (5) can be written in homogeneous form as
--- follows:
---
---    A~ * x = 0,                                                    (7)
---
--- where
---
---    A~ = (I | -A)                                                  (8)
---
--- is an augmented constraint matrix (has m rows and m+n columns), I is
--- the unity matrix of the order m. Note that in the structure LPX only
--- the original constraint matrix A is explicitly stored.
---
--- The current basis is defined by partitioning columns of the matrix
--- A~ into basic and non-basic ones, in which case the system (7) can
--- be written as
---
---    B * xB + N * xN = 0,                                           (9)
---
--- where B is a square non-sigular mxm matrix built of basic columns
--- and called the basis matrix, N is a mxn matrix built of non-basic
--- columns, xB is vector of basic variables, xN is vector of non-basic
--- variables.
---
--- Using the partitioning (9) the LP problem (4)-(6) can be written in
--- a form, which defines components of the corresponding basic solution
--- and is called the simplex table:
---
---    Z = d * xN + c[0]                                             (10)
---
---    xB = A^ * xN                                                  (11)
---
---    lB <= xB <= uB                                                (12)
---
---    lN <= xN <= uN                                                (13)
---
--- where:
---
---    A^ = (alfa[i,j]) = - inv(B) * N                               (14)
---
--- is the mxn matrix of influence coefficients;
---
---    d = (d[j]) = cN - N' * pi                                     (15)
---
--- is the vector of reduced costs of non-basic variables; and
---
---    pi = (pi[i]) = inv(B') * cB                                   (16)
---
--- is the vector of simplex (Lagrange) multipliers, which correspond to
--- the equiality constraints (5).
---
--- Note that signs of the reduced costs d are determined by the formula
--- (15) in both cases of minimization and maximization.
---
--- The structure LPX allows scaling the problem. In the scaled problem
--- the constraint matrix is scaled and has the form:
---
---    A" = R * A * S,                                               (17)
---
--- where A is the constraint matrix of the original (unscaled) problem,
--- R and S are, respectively, diagonal scaling mxm and nxn matrices with
--- positive diagonal elements used to scale rows and columns of A.
---
--- The connection between the original and scaled components is defined
--- by (17) and expressed with the following formulae:
---
---    c"  = S * c          (objective coefficients)
---
---    xR" = R * xR         (values of auxiliary variables)
---    lR" = R * lR         (lower bounds of auxiliary variables)
---    uR" = R * uR         (upper bounds of auxiliary variables)
---
---    xS" = inv(S) * xS    (values of structural variables)
---    lS" = inv(S) * lS    (lower bounds of structural variables)
---    uS" = inv(S) * uS    (upper bounds of structural variables)
---
---    A"  = R * A * S      (constraint matrix)
---
--- Note that substitution scaled components into (4)-(6) gives the same
--- LP problem. */
+#ifdef _GLPAPI_PRIVATE
+#include "glpavl.h"
+#include "glpscs.h"
 
-#define LPX glp_prob
-
-#ifndef _GLP_PROB
-#define _GLP_PROB
-
-typedef struct LPX LPX;
-typedef struct LPXROW LPXROW;
-typedef struct LPXCOL LPXCOL;
-typedef struct LPXAIJ LPXAIJ;
-typedef struct LPXCPS LPXCPS;
+typedef struct glp_prob glp_prob;
+typedef struct GLPROW GLPROW;
+typedef struct GLPCOL GLPCOL;
+typedef struct GLPAIJ GLPAIJ;
 
 struct glp_prob
 {     /* LP/MIP problem object */
-      /*--------------------------------------------------------------*/
-      /* memory management */
-      DMP *row_pool;
-      /* memory pool for LPXROW objects */
-      DMP *col_pool;
-      /* memory pool for LPXCOL objects */
-      DMP *aij_pool;
-      /* memory pool for LPXAIJ objects */
-      DMP *str_pool;
-      /* memory pool for segmented character strings */
+      DMP *pool;
+      /* memory pool to store problem object components */
+      void *cps; /* struct LPXCPS *cps; */
+      /* reserved for downward compatibility */
       char *str_buf; /* char str_buf[255+1]; */
-      /* working buffer to store character strings */
+      /* working buffer to store null-terminated character strings */
       /*--------------------------------------------------------------*/
       /* LP/MIP data */
-      STR *name;
+      SCS *name;
       /* problem name (1 to 255 chars); NULL means no name is assigned
          to the problem */
-      STR *obj;
+      SCS *obj;
       /* objective function name (1 to 255 chars); NULL means no name
          is assigned to the objective function */
       int dir;
@@ -214,81 +67,77 @@ struct glp_prob
       /* number of rows, 0 <= m <= m_max */
       int n;
       /* number of columns, 0 <= n <= n_max */
-      int nz;
-      /* number of non-zero constraint coefficients */
-      LPXROW **row; /* LPXROW *row[1+m_max]; */
+      int nnz;
+      /* number of non-zero constraint coefficients, nnz >= 0 */
+      GLPROW **row; /* GLPROW *row[1+m_max]; */
       /* row[0] is not used;
          row[i], 1 <= i <= m, is a pointer to i-th row */
-      LPXCOL **col; /* LPXCOL *col[1+n_max]; */
+      GLPCOL **col; /* GLPCOL *col[1+n_max]; */
       /* col[0] is not used;
          col[j], 1 <= j <= n, is a pointer to j-th column */
-      AVLTREE *r_tree;
+      AVL *r_tree;
       /* row index to find rows by their names; NULL means this index
          does not exist */
-      AVLTREE *c_tree;
+      AVL *c_tree;
       /* column index to find columns by their names; NULL means this
          index does not exist */
       /*--------------------------------------------------------------*/
-      /* LP basis matrix */
-      BFI *b_inv; /* BFI b_inv[1:m,1:m]; */
-      /* factorization (invertable form) of the current basis matrix */
+      /* basis factorization */
+      int valid;
+      /* this flag is set iff the basis factorization is valid */
       int *basis; /* int basis[1+m_max]; */
-      /* basis header (valid only if the factorization is valid):
+      /* basis header (valid only if the factorization is valid);
          basis[0] is not used;
          basis[i] = k is the ordinal number of auxiliary (1 <= k <= m)
          or structural (m+1 <= k <= m+n) variable which corresponds to
          i-th basic variable xB[i], 1 <= i <= m */
+      BFI *binv; /* BFI binv[1:m,1:m]; */
+      /* current basis factorization; NULL means the factorization does
+         not exist */
       /*--------------------------------------------------------------*/
-      /* LP/MIP solution */
-      int p_stat;
-      /* status of primal basic solution: */
-#if 0
-#define LPX_P_UNDEF     132   /* primal solution is undefined */
-#define LPX_P_FEAS      133   /* solution is primal feasible */
-#define LPX_P_INFEAS    134   /* solution is primal infeasible */
-#define LPX_P_NOFEAS    135   /* no primal feasible solution exists */
-#endif
-      int d_stat;
-      /* status of dual basic solution: */
-#if 0
-#define LPX_D_UNDEF     136   /* dual solution is undefined */
-#define LPX_D_FEAS      137   /* solution is dual feasible */
-#define LPX_D_INFEAS    138   /* solution is dual infeasible */
-#define LPX_D_NOFEAS    139   /* no dual feasible solution exists */
-#endif
+      /* basic solution (LP) */
+      int pbs_stat;
+      /* primal basic solution status:
+         GLP_UNDEF  - primal solution is undefined
+         GLP_FEAS   - primal solution is feasible
+         GLP_INFEAS - primal solution is infeasible
+         GLP_NOFEAS - no primal feasible solution exists */
+      int dbs_stat;
+      /* dual basic solution status:
+         GLP_UNDEF  - dual solution is undefined
+         GLP_FEAS   - dual solution is feasible
+         GLP_INFEAS - dual solution is infeasible
+         GLP_NOFEAS - no dual feasible solution exists */
+      double obj_val;
+      /* objective function value */
       int some;
-      /* ordinal number of some auxiliary or structural variable which
-         has certain property, 0 <= some <= m+n */
-      double b_obj;
-      /* objective function value (basic solution) */
-      int t_stat;
-      /* status of interior-point solution: */
-#if 0
-#define LPX_T_UNDEF     150   /* interior solution is undefined */
-#define LPX_T_OPT       151   /* interior solution is optimal */
-#endif
-      double t_obj;
-      /* objective function value (interior-point solution) */
-      int i_stat;
-      /* status of integer solution: */
-#if 0
-#define LPX_I_UNDEF     170   /* integer solution is undefined */
-#define LPX_I_OPT       171   /* integer solution is optimal */
-#define LPX_I_FEAS      172   /* integer solution is feasible */
-#define LPX_I_NOFEAS    173   /* no integer solution exists */
-#endif
-      double i_obj;
-      /* objective function value (integer solution) */
+      /* ordinal number of some auxiliary or structural variable having
+         certain property, 0 <= some <= m+n */
       /*--------------------------------------------------------------*/
-      LPXCPS *cps;
-      /* control parameters and statistics */
+      /* interior-point solution (LP) */
+      int ipt_stat;
+      /* interior-point solution status:
+         GLP_UNDEF  - interior solution is undefined
+         GLP_OPT    - interior solution is optimal */
+      double ipt_obj;
+      /* objective function value */
+      /*--------------------------------------------------------------*/
+      /* integer solution (MIP) */
+      int mip_stat;
+      /* integer solution status:
+         GLP_UNDEF  - integer solution is undefined
+         GLP_OPT    - integer solution is optimal
+         GLP_FEAS   - integer solution is feasible
+         GLP_NOFEAS - no integer solution exists */
+      double mip_obj;
+      /* objective function value */
 };
 
-struct LPXROW
+struct GLPROW
 {     /* LP/MIP row (auxiliary variable) */
       int i;
       /* ordinal number (1 to m) assigned to this row */
-      STR *name;
+      SCS *name;
       /* row name (1 to 255 chars); NULL means no name is assigned to
          this row */
       AVLNODE *node;
@@ -307,12 +156,12 @@ struct LPXROW
       double ub; /* non-scaled */
       /* upper bound; if the row has no upper bound, ub is zero */
       /* if the row type is GLP_FX, ub is equal to lb */
-      LPXAIJ *ptr; /* non-scaled */
+      GLPAIJ *ptr; /* non-scaled */
       /* pointer to doubly linked list of constraint coefficients which
          are placed in this row */
       double rii;
-      /* diagonal element r[i,i] of the scaling matrix R (see (17)) for
-         this row; if the scaling is not used, r[i,i] is 1 */
+      /* diagonal element r[i,i] of scaling matrix R for this row;
+         if the scaling is not used, r[i,i] is 1 */
       int stat;
       /* status of the auxiliary variable:
          GLP_BS - basic variable
@@ -320,11 +169,10 @@ struct LPXROW
          GLP_NU - non-basic variable on upper bound
          GLP_NF - non-basic free variable
          GLP_NS - non-basic fixed variable */
-      int b_ind;
-      /* if the auxiliary variable is basic (LPX_BS), lpx.basis[b_ind]
-         refers to this row; if the auxiliary variable is non-basic,
-         b_ind is 0; this attribute is valid only if the factorization
-         of the basis matrix is valid */
+      int bind;
+      /* if the auxiliary variable is basic, basis[bind] refers to this
+         row, otherwise, bind is 0; this attribute is valid only if the
+         basis factorization is valid */
       double prim; /* non-scaled */
       /* primal value of the auxiliary variable in basic solution */
       double dual; /* non-scaled */
@@ -337,11 +185,11 @@ struct LPXROW
       /* primal value of the auxiliary variable in integer solution */
 };
 
-struct LPXCOL
+struct GLPCOL
 {     /* LP/MIP column (structural variable) */
       int j;
       /* ordinal number (1 to n) assigned to this column */
-      STR *name;
+      SCS *name;
       /* column name (1 to 255 chars); NULL means no name is assigned
          to this column */
       AVLNODE *node;
@@ -366,12 +214,12 @@ struct LPXCOL
       /* if the column type is GLP_FX, ub is equal to lb */
       double coef; /* non-scaled */
       /* objective coefficient at the structural variable */
-      LPXAIJ *ptr; /* non-scaled */
+      GLPAIJ *ptr; /* non-scaled */
       /* pointer to doubly linked list of constraint coefficients which
          are placed in this column */
       double sjj;
-      /* diagonal element s[j,j] of the scaling matrix S (see (17)) for
-         this column; if the scaling is not used, s[j,j] is 1 */
+      /* diagonal element s[j,j] of scaling matrix S for this column;
+         if the scaling is not used, s[j,j] is 1 */
       int stat;
       /* status of the structural variable:
          GLP_BS - basic variable
@@ -379,11 +227,10 @@ struct LPXCOL
          GLP_NU - non-basic variable on upper bound
          GLP_NF - non-basic free variable
          GLP_NS - non-basic fixed variable */
-      int b_ind;
-      /* if the structural variable is basic (LPX_BS), lpx.basis[b_ind]
-         refers to this column; if the structural variable is non-basic,
-         b_ind is 0; this attribute is valid only if the factorization
-         of the basis matrix is valid */
+      int bind;
+      /* if the structural variable is basic, basis[bind] refers to
+         this column; otherwise, bind is 0; this attribute is valid only
+         if the basis factorization is valid */
       double prim; /* non-scaled */
       /* primal value of the structural variable in basic solution */
       double dual; /* non-scaled */
@@ -396,24 +243,30 @@ struct LPXCOL
       /* primal value of the structural variable in integer solution */
 };
 
-struct LPXAIJ
-{     /* constraint coefficient a[i,j]; see (2) and (5) */
-      LPXROW *row;
+struct GLPAIJ
+{     /* constraint coefficient a[i,j] */
+      GLPROW *row;
       /* pointer to row, where this coefficient is placed */
-      LPXCOL *col;
+      GLPCOL *col;
       /* pointer to column, where this coefficient is placed */
       double val;
       /* numeric (non-zero) value of this coefficient */
-      LPXAIJ *r_prev;
+      GLPAIJ *r_prev;
       /* pointer to previous coefficient in the same row */
-      LPXAIJ *r_next;
+      GLPAIJ *r_next;
       /* pointer to next coefficient in the same row */
-      LPXAIJ *c_prev;
+      GLPAIJ *c_prev;
       /* pointer to previous coefficient in the same column */
-      LPXAIJ *c_next;
+      GLPAIJ *c_next;
       /* pointer to next coefficient in the same column */
 };
+#endif
 
+#include "glpk.h"
+
+/**********************************************************************/
+
+#ifdef _GLPAPI_PRIVATE
 struct LPXCPS
 {     /* control parameters and statistics */
       int msg_lev;
@@ -549,161 +402,161 @@ struct LPXCPS
          columns by binary ones */
       int use_cuts; /* lpx_intopt */
       /* if this flag is set, the routine lpx_intopt tries generating
-         cutting planes: */
-#if 0
-#define LPX_C_COVER     0x01  /* mixed cover cuts */
-#define LPX_C_CLIQUE    0x02  /* clique cuts */
-#define LPX_C_GOMORY    0x04  /* Gomory's mixed integer cuts */
-#define LPX_C_ALL       0xFF  /* all cuts */
-#endif
+         cutting planes:
+         LPX_C_COVER  - mixed cover cuts
+         LPX_C_CLIQUE - clique cuts
+         LPX_C_GOMORY - Gomory's mixed integer cuts
+         LPX_C_ALL    - all cuts */
+      int bf_type; /* lpx_simplex */
+      /* type of LP basis factorization used:
+         1 - LU + Forrest-Tomlin update
+         2 - LU + Schur complement + Bartels-Golub update
+         3 - LU + Schur complement + Givens rotation update */
 };
-
 #endif
 
-/**********************************************************************/
-
 /* basis status: */
 #define LPX_B_UNDEF     130   /* current basis is undefined */
 #define LPX_B_VALID     131   /* current basis is valid */
 
-#define lpx_order_matrix      _glp_lpx_order_matrix
+#define lpx_order_matrix _glp_lpx_order_matrix
 void lpx_order_matrix(LPX *lp);
 /* order rows and columns of the constraint matrix */
 
-#define lpx_set_rii           _glp_lpx_set_rii
+#define lpx_set_rii _glp_lpx_set_rii
 void lpx_set_rii(LPX *lp, int i, double rii);
 /* set (change) row scale factor */
 
-#define lpx_set_sjj           _glp_lpx_set_sjj
+#define lpx_set_sjj _glp_lpx_set_sjj
 void lpx_set_sjj(LPX *lp, int j, double sjj);
 /* set (change) column scale factor */
 
-#define lpx_put_lp_basis      _glp_lpx_put_lp_basis
+void glp_put_solution(glp_prob *lp, int inval, const int *p_stat,
+      const int *d_stat, const double *obj_val, const int r_stat[],
+      const double r_prim[], const double r_dual[], const int c_stat[],
+      const double c_prim[], const double c_dual[]);
+/* store basic solution components */
+
+#define lpx_put_lp_basis _glp_lpx_put_lp_basis
 void lpx_put_lp_basis(LPX *lp, int b_stat, int basis[], BFI *b_inv);
 /* store LP basis information */
 
-#define lpx_put_solution      _glp_lpx_put_solution
-void lpx_put_solution(LPX *lp, int p_stat, int d_stat,
-      int row_stat[], double row_prim[], double row_dual[],
-      int col_stat[], double col_prim[], double col_dual[]);
-/* store basic solution components */
-
-#define lpx_put_ray_info      _glp_lpx_put_ray_info
+#define lpx_put_ray_info _glp_lpx_put_ray_info
 void lpx_put_ray_info(LPX *lp, int k);
 /* store row/column which causes unboundness */
 
-#define lpx_put_ipt_soln      _glp_lpx_put_ipt_soln
+#define lpx_put_ipt_soln _glp_lpx_put_ipt_soln
 void lpx_put_ipt_soln(LPX *lp, int t_stat, double row_pval[],
       double row_dval[], double col_pval[], double col_dval[]);
 /* store interior-point solution components */
 
-#define lpx_put_mip_soln      _glp_lpx_put_mip_soln
+#define lpx_put_mip_soln _glp_lpx_put_mip_soln
 void lpx_put_mip_soln(LPX *lp, int i_stat, double row_mipx[],
       double col_mipx[]);
 /* store mixed integer solution components */
 
-#define lpx_get_rii           _glp_lpx_get_rii
+#define lpx_get_rii _glp_lpx_get_rii
 double lpx_get_rii(LPX *lp, int i);
 /* retrieve row scale factor */
 
-#define lpx_get_sjj           _glp_lpx_get_sjj
+#define lpx_get_sjj _glp_lpx_get_sjj
 double lpx_get_sjj(LPX *lp, int j);
 /* retrieve column scale factor */
 
-#define lpx_is_b_avail        _glp_lpx_is_b_avail
+#define lpx_is_b_avail _glp_lpx_is_b_avail
 int lpx_is_b_avail(LPX *lp);
 /* check if LP basis is available */
 
-#define lpx_get_b_info        _glp_lpx_get_b_info
+#define lpx_get_b_info _glp_lpx_get_b_info
 int lpx_get_b_info(LPX *lp, int i);
 /* retrieve LP basis information */
 
-#define lpx_get_row_b_ind     _glp_lpx_get_row_b_ind
+#define lpx_get_row_b_ind _glp_lpx_get_row_b_ind
 int lpx_get_row_b_ind(LPX *lp, int i);
 /* retrieve row index in LP basis */
 
-#define lpx_get_col_b_ind     _glp_lpx_get_col_b_ind
+#define lpx_get_col_b_ind _glp_lpx_get_col_b_ind
 int lpx_get_col_b_ind(LPX *lp, int j);
 /* retrieve column index in LP basis */
 
-#define lpx_access_inv        _glp_lpx_access_inv
+#define lpx_access_inv _glp_lpx_access_inv
 BFI *lpx_access_inv(LPX *lp);
 /* access factorization of basis matrix */
 
-#define lpx_invert            _glp_lpx_invert
+#define lpx_invert _glp_lpx_invert
 int lpx_invert(LPX *lp);
 /* compute factorization of basis matrix */
 
-#define lpx_ftran             _glp_lpx_ftran
+#define lpx_ftran _glp_lpx_ftran
 void lpx_ftran(LPX *lp, double x[]);
 /* forward transformation (solve system B*x = b) */
 
-#define lpx_btran             _glp_lpx_btran
+#define lpx_btran _glp_lpx_btran
 void lpx_btran(LPX *lp, double x[]);
 /* backward transformation (solve system B'*x = b) */
 
-#define lpx_eval_b_prim       _glp_lpx_eval_b_prim
+#define lpx_eval_b_prim _glp_lpx_eval_b_prim
 void lpx_eval_b_prim(LPX *lp, double row_prim[], double col_prim[]);
 /* compute primal basic solution components */
 
-#define lpx_eval_b_dual       _glp_lpx_eval_b_dual
+#define lpx_eval_b_dual _glp_lpx_eval_b_dual
 void lpx_eval_b_dual(LPX *lp, double row_dual[], double col_dual[]);
 /* compute dual basic solution components */
 
-#define lpx_remove_tiny       _glp_lpx_remove_tiny
+#define lpx_remove_tiny _glp_lpx_remove_tiny
 int lpx_remove_tiny(int ne, int ia[], int ja[], double ar[],
       double eps);
 /* remove zero and tiny elements */
 
-#define lpx_reduce_form       _glp_lpx_reduce_form
+#define lpx_reduce_form _glp_lpx_reduce_form
 int lpx_reduce_form(LPX *lp, int len, int ind[], double val[],
       double work[]);
 /* reduce linear form */
 
-#define lpx_eval_row          _glp_lpx_eval_row
+#define lpx_eval_row _glp_lpx_eval_row
 double lpx_eval_row(LPX *lp, int len, int ind[], double val[]);
 /* compute explicitly specified row */
 
-#define lpx_eval_degrad       _glp_lpx_eval_degrad
+#define lpx_eval_degrad _glp_lpx_eval_degrad
 double lpx_eval_degrad(LPX *lp, int len, int ind[], double val[],
       int type, double rhs);
 /* compute degradation of the objective function */
 
-#define lpx_gomory_cut        _glp_lpx_gomory_cut
+#define lpx_gomory_cut _glp_lpx_gomory_cut
 int lpx_gomory_cut(LPX *lp, int len, int ind[], double val[],
       double work[]);
 /* generate Gomory's mixed integer cut */
 
-#define lpx_cover_cut         _glp_lpx_cover_cut
+#define lpx_cover_cut _glp_lpx_cover_cut
 int lpx_cover_cut(LPX *lp, int len, int ind[], double val[],
       double work[]);
 /* generate mixed cover cut */
 
-#define lpx_create_cog        _glp_lpx_create_cog
+#define lpx_create_cog _glp_lpx_create_cog
 void *lpx_create_cog(LPX *lp);
 /* create the conflict graph */
 
-#define lpx_add_cog_edge      _glp_lpx_add_cog_edge
+#define lpx_add_cog_edge _glp_lpx_add_cog_edge
 void lpx_add_cog_edge(void *cog, int i, int j);
 /* add edge to the conflict graph */
 
-#define lpx_clique_cut        _glp_lpx_clique_cut
+#define lpx_clique_cut _glp_lpx_clique_cut
 int lpx_clique_cut(LPX *lp, void *cog, int ind[], double val[]);
 /* generate clique cut */
 
-#define lpx_delete_cog        _glp_lpx_delete_cog
+#define lpx_delete_cog _glp_lpx_delete_cog
 void lpx_delete_cog(void *cog);
 /* delete the conflict graph */
 
-#define lpx_extract_prob      _glp_lpx_extract_prob
+#define lpx_extract_prob _glp_lpx_extract_prob
 LPX *lpx_extract_prob(void *mpl);
 /* extract problem instance from MathProg model */
 
-#define lpx_read_prob         _glp_lpx_read_prob
+#define lpx_read_prob _glp_lpx_read_prob
 LPX *lpx_read_prob(char *fname);
 /* read problem data in GNU LP format */
 
-#define lpx_write_prob        _glp_lpx_write_prob
+#define lpx_write_prob _glp_lpx_write_prob
 int lpx_write_prob(LPX *lp, char *fname);
 /* write problem data in GNU LP format */
 
