@@ -26,7 +26,7 @@
 #ifndef _GLPIET_H
 #define _GLPIET_H
 
-#include "glpstr.h"
+#include "glpscs.h"
 
 typedef struct IET IET;       /* implicit enumeration tree */
 typedef struct IETNPS IETNPS; /* node (sub)problem slot */
@@ -226,7 +226,7 @@ struct IETRGD
 {     /* row global descriptor */
       IETNPD *host;
       /* pointer to the subproblem where this row was introduced */
-      STR *name;
+      SCS *name;
       /* row name (1 to 255 chars); NULL means no name is assigned to
          this row */
       int i;
@@ -245,7 +245,7 @@ struct IETCGD
 {     /* column global descriptor */
       IETNPD *host;
       /* pointer to subproblem where this column was introduced */
-      STR *name;
+      SCS *name;
       /* column name (1 to 255 chars); NULL means no name is assigned
          to this column */
       int j;
