@@ -1,27 +1,27 @@
 /* glpk.h */
 
-/*----------------------------------------------------------------------
--- This code is part of GNU Linear Programming Kit (GLPK).
---
--- Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
--- Department for Applied Informatics, Moscow Aviation Institute,
--- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
---
--- GLPK is free software; you can redistribute it and/or modify it
--- under the terms of the GNU General Public License as published by
--- the Free Software Foundation; either version 2, or (at your option)
--- any later version.
---
--- GLPK is distributed in the hope that it will be useful, but WITHOUT
--- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
--- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
--- License for more details.
---
--- You should have received a copy of the GNU General Public License
--- along with GLPK; see the file COPYING. If not, write to the Free
--- Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
--- 02110-1301, USA.
-----------------------------------------------------------------------*/
+/***********************************************************************
+*  This code is part of GNU Linear Programming Kit (GLPK).
+*
+*  Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
+*  Department for Applied Informatics, Moscow Aviation Institute,
+*  Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
+*
+*  GLPK is free software; you can redistribute it and/or modify it
+*  under the terms of the GNU General Public License as published by
+*  the Free Software Foundation; either version 2, or (at your option)
+*  any later version.
+*
+*  GLPK is distributed in the hope that it will be useful, but WITHOUT
+*  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+*  or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
+*  License for more details.
+*
+*  You should have received a copy of the GNU General Public License
+*  along with GLPK; see the file COPYING. If not, write to the Free
+*  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+*  02110-1301, USA.
+***********************************************************************/
 
 #ifndef _GLPK_H
 #define _GLPK_H
@@ -32,42 +32,46 @@ extern "C" {
 
 /* library version numbers: */
 #define GLP_MAJOR_VERSION  4
-#define GLP_MINOR_VERSION  16
+#define GLP_MINOR_VERSION  17
 
-/* optimization direction flag: */
-#define GLP_MIN   1  /* minimization */
-#define GLP_MAX   2  /* maximization */
-
-/* kind of structural variable: */
-#define GLP_CV    1  /* continuous variable */
-#define GLP_IV    2  /* integer variable */
-#define GLP_BV    3  /* binary variable */
-
-/* type of auxiliary/structural variable: */
-#define GLP_FR    1  /* free variable */
-#define GLP_LO    2  /* variable with lower bound */
-#define GLP_UP    3  /* variable with upper bound */
-#define GLP_DB    4  /* double-bounded variable */
-#define GLP_FX    5  /* fixed variable */
-
-/* status of auxiliary/structural variable: */
-#define GLP_BS    1  /* basic variable */
-#define GLP_NL    2  /* non-basic variable on lower bound */
-#define GLP_NU    3  /* non-basic variable on upper bound */
-#define GLP_NF    4  /* non-basic free variable */
-#define GLP_NS    5  /* non-basic fixed variable */
-
-#ifndef _GLP_PROB
-#define _GLP_PROB
+#ifndef _GLPAPI_PRIVATE
 typedef struct { double _prob; } glp_prob;
 /* LP/MIP problem object */
 #endif
 
-#ifndef _GLP_ULONG
-#define _GLP_ULONG
+/* optimization direction flag: */
+#define GLP_MIN         1  /* minimization */
+#define GLP_MAX         2  /* maximization */
+
+/* kind of structural variable: */
+#define GLP_CV          1  /* continuous variable */
+#define GLP_IV          2  /* integer variable */
+#define GLP_BV          3  /* binary variable */
+
+/* type of auxiliary/structural variable: */
+#define GLP_FR          1  /* free variable */
+#define GLP_LO          2  /* variable with lower bound */
+#define GLP_UP          3  /* variable with upper bound */
+#define GLP_DB          4  /* double-bounded variable */
+#define GLP_FX          5  /* fixed variable */
+
+/* status of auxiliary/structural variable: */
+#define GLP_BS          1  /* basic variable */
+#define GLP_NL          2  /* non-basic variable on lower bound */
+#define GLP_NU          3  /* non-basic variable on upper bound */
+#define GLP_NF          4  /* non-basic free variable */
+#define GLP_NS          5  /* non-basic fixed variable */
+
+/* solution status: */
+#define GLP_UNDEF       1  /* solution is undefined */
+#define GLP_FEAS        2  /* solution is feasible */
+#define GLP_INFEAS      3  /* solution is infeasible */
+#define GLP_NOFEAS      4  /* no feasible solution exists */
+#define GLP_OPT         5  /* solution is optimal */
+#define GLP_UNBND       6  /* solution is unbounded */
+
 typedef struct { unsigned int lo, hi; } glp_ulong;
 /* 64-bit unsigned integer data type */
-#endif
 
 glp_prob *glp_create_prob(void);
 /* create problem object */
@@ -194,6 +198,15 @@ void glp_set_row_stat(glp_prob *lp, int i, int stat);
 void glp_set_col_stat(glp_prob *lp, int j, int stat);
 /* set (change) column status */
 
+int glp_get_status(glp_prob *lp);
+/* retrieve generic status of basic solution */
+
+int glp_get_prim_stat(glp_prob *lp);
+/* retrieve status of primal basic solution */
+
+int glp_get_dual_stat(glp_prob *lp);
+/* retrieve status of dual basic solution */
+
 double glp_get_obj_val(glp_prob *lp);
 /* retrieve objective value (basic solution) */
 
@@ -263,7 +276,7 @@ void glp_mem_usage(int *count, int *cpeak, glp_ulong *total,
 
 /**********************************************************************/
 
-#ifndef GLP_DISABLE_OLD_API
+#define LPX glp_prob
 
 /* problem class: */
 #define LPX_LP          100   /* linear programming (LP) */
@@ -369,14 +382,13 @@ void glp_mem_usage(int *count, int *cpeak, glp_ulong *total,
 #define LPX_K_PRESOL    327   /* lp->presol */
 #define LPX_K_BINARIZE  328   /* lp->binarize */
 #define LPX_K_USECUTS   329   /* lp->use_cuts */
+#define LPX_K_BFTYPE    330   /* lp->bf_type */
 
 #define LPX_C_COVER     0x01  /* mixed cover cuts */
 #define LPX_C_CLIQUE    0x02  /* clique cuts */
 #define LPX_C_GOMORY    0x04  /* Gomory's mixed integer cuts */
 #define LPX_C_ALL       0xFF  /* all cuts */
 
-#define LPX glp_prob
-
 typedef struct
 {     /* this structure contains results reported by the routines which
          checks Karush-Kuhn-Tucker conditions (for details see comments
@@ -577,7 +589,7 @@ double lpx_get_row_ub(LPX *lp, int i);
 #define lpx_get_row_bnds _glp_lpx_get_row_bnds
 void lpx_get_row_bnds(LPX *lp, int i, int *typx, double *lb,
       double *ub);
-/* retrieve row bounds (obsolete) */
+/* retrieve row bounds */
 
 #define lpx_get_col_type _glp_lpx_get_col_type
 int lpx_get_col_type(LPX *lp, int j);
@@ -594,7 +606,7 @@ double lpx_get_col_ub(LPX *lp, int j);
 #define lpx_get_col_bnds _glp_lpx_get_col_bnds
 void lpx_get_col_bnds(LPX *lp, int j, int *typx, double *lb,
       double *ub);
-/* retrieve column bounds (obsolete) */
+/* retrieve column bounds */
 
 #define lpx_get_obj_coef _glp_lpx_get_obj_coef
 double lpx_get_obj_coef(LPX *lp, int j);
@@ -692,6 +704,11 @@ double lpx_get_row_prim(LPX *lp, int i);
 double lpx_get_row_dual(LPX *lp, int i);
 /* retrieve row dual value (basic solution) */
 
+#define lpx_get_row_info _glp_lpx_get_row_info
+void lpx_get_row_info(LPX *lp, int i, int *tagx, double *vx,
+      double *dx);
+/* obtain row solution information */
+
 #define lpx_get_col_stat _glp_lpx_get_col_stat
 int lpx_get_col_stat(LPX *lp, int j);
 /* retrieve column status (basic solution) */
@@ -704,11 +721,6 @@ double lpx_get_col_prim(LPX *lp, int j);
 double lpx_get_col_dual(glp_prob *lp, int j);
 /* retrieve column dual value (basic solution) */
 
-#define lpx_get_row_info _glp_lpx_get_row_info
-void lpx_get_row_info(LPX *lp, int i, int *tagx, double *vx,
-      double *dx);
-/* obtain row solution information (obsolete) */
-
 #define lpx_get_col_info _glp_lpx_get_col_info
 void lpx_get_col_info(LPX *lp, int j, int *tagx, double *vx,
       double *dx);
@@ -909,8 +921,6 @@ int lpx_print_ips(LPX *lp, const char *fname);
 int lpx_print_mip(LPX *lp, const char *fname);
 /* write MIP problem solution in printable format */
 
-#endif
-
 #ifdef __cplusplus
 }
 #endif
