@@ -77,6 +77,11 @@ ulong_t ulmul(ulong_t x, ulong_t y);
 uldiv_t uldiv(ulong_t x, ulong_t y);
 /* divide unsigned long integers */
 
+#define ultoa _glp_lib_ultoa
+char *ultoa(ulong_t x, char *s, int radix);
+/* convert unsigned long integer to character string */
+
+#ifdef _GLPLIB_PRIVATE
 #define lib_set_ptr _glp_lib_set_ptr
 void lib_set_ptr(void *ptr);
 /* store global pointer in TLS */
@@ -84,7 +89,9 @@ void lib_set_ptr(void *ptr);
 #define lib_get_ptr _glp_lib_get_ptr
 void *lib_get_ptr(void);
 /* retrieve global pointer from TLS */
+#endif
 
+#ifdef _GLPLIB_PRIVATE
 typedef struct LIBENV LIBENV;
 typedef struct LIBMEM LIBMEM;
 
@@ -141,14 +148,21 @@ struct LIBMEM
       LIBMEM *next;
       /* pointer to next memory block descriptor */
 };
+#endif
 
 #define lib_init_env _glp_lib_init_env
 int lib_init_env(void);
 /* initialize library environment */
 
+#ifdef _GLPLIB_PRIVATE
 #define lib_link_env _glp_lib_link_env
 LIBENV *lib_link_env(void);
 /* retrieve pointer to library environmental block */
+#endif
+
+#define lib_version _glp_lib_version
+const char *lib_version(void);
+/* determine library version */
 
 #define lib_free_env _glp_lib_free_env
 int lib_free_env(void);
@@ -166,6 +180,10 @@ void xprintf(const char *fmt, ...);
 void xprint1(const char *fmt, ...);
 /* (obsolete) */
 
+#define lib_term_hook _glp_lib_term_hook
+void lib_term_hook(int (*func)(void *info, const char *s), void *info);
+/* install hook to intercept terminal output */
+
 #define lib_print_hook _glp_lib_print_hook
 void lib_print_hook(int (*func)(void *info, char *buf), void *info);
 /* (obsolete) */
@@ -210,6 +228,15 @@ void *xcalloc(int n, int size);
 void xfree(void *ptr);
 /* free memory block */
 
+#define lib_mem_limit _glp_lib_mem_limit
+void lib_mem_limit(ulong_t limit);
+/* set memory allocation limit */
+
+#define lib_mem_usage _glp_lib_mem_usage
+void lib_mem_usage(int *count, int *cpeak, ulong_t *total,
+      ulong_t *tpeak);
+/* get memory usage information */
+
 #define xfopen _glp_lib_xfopen
 FILE *xfopen(const char *fname, const char *mode);
 /* open file */
@@ -250,6 +277,10 @@ char *strspx(char *str);
 char *strtrim(char *str);
 /* remove trailing spaces from character string */
 
+#define strrev _glp_lib_strrev
+char *strrev(char *s);
+/* reverse character string */
+
 #define fp2rat _glp_lib_fp2rat
 int fp2rat(double x, double eps, double *p, double *q);
 /* convert floating-point number to rational number */
