@@ -26,9 +26,8 @@
 #ifndef _GLPMPL_H
 #define _GLPMPL_H
 
-#include <setjmp.h>
-#include <stdio.h>
 #include "glpavl.h"
+#include "glpdmp.h"
 #include "glprng.h"
 
 typedef struct MPL MPL;
@@ -210,7 +209,7 @@ struct MPL
       DMP *pool;
       /* memory pool used to allocate all data instances created during
          the translation phase */
-      AVLTREE *tree;
+      AVL *tree;
       /* symbolic name table:
          node.type = A_INDEX     => node.link -> DOMAIN_SLOT
          node.type = A_SET       => node.link -> SET
@@ -1415,7 +1414,7 @@ struct ARRAY
       /* the first array member; NULL means the array is empty */
       MEMBER *tail;
       /* the last array member; NULL means the array is empty */
-      AVLTREE *tree;
+      AVL *tree;
       /* the search tree intended to find array members for logarithmic
          time; NULL means the search tree doesn't exist */
       ARRAY *prev;
