@@ -25,8 +25,8 @@
 
 #include "glpdmp.h"
 #include "glpgmp.h"
-#include "glplib.h"
 #define fault xfault1
+#define dmp_create_poolx(size) dmp_create_pool()
 
 #ifdef HAVE_GMP_H             /* use GNU MP library */
 
@@ -46,21 +46,21 @@ void *gmp_get_atom(void)
          xassert(sizeof(int) == 4);
          xassert(sizeof(struct mpz) <= sizeof(struct mpz_seg));
          xassert(sizeof(struct mpq) <= sizeof(struct mpz_seg));
-         gmp_pool = dmp_create_pool(sizeof(struct mpz_seg));
+         gmp_pool = dmp_create_poolx(sizeof(struct mpz_seg));
       }
-      return dmp_get_atom(gmp_pool);
+      return dmp_get_atom(gmp_pool, sizeof(struct mpz_seg));
 }
 
 void gmp_free_atom(void *ptr)
 {     xassert(gmp_pool != NULL);
-      dmp_free_atom(gmp_pool, ptr);
+      dmp_free_atom(gmp_pool, ptr, sizeof(struct mpz_seg));
 }
 
 int gmp_pool_count(void)
 {     if (gmp_pool == NULL)
          return 0;
       else
-         return gmp_pool->count;
+         return dmp_in_use(gmp_pool).lo;
 }
 
 unsigned short *gmp_get_work(int size)
