@@ -23,9 +23,9 @@
 -- 02110-1301, USA.
 ----------------------------------------------------------------------*/
 
-#include "glplib.h"
 #include "glpios.h"
 #define fault xfault1
+#define dmp_create_poolx(size) dmp_create_pool()
 
 /**********************************************************************/
 /* * *               LOW-LEVEL MAINTENANCE ROUTINES               * * */
@@ -44,7 +44,7 @@ void ios_attach_npd(IOS *ios, int p)
 {     IOSNPD *node;
       node = ios_get_npd_ptr(ios, p);
       xassert(node == NULL);
-      node = dmp_get_atom(ios->npd_pool);
+      node = dmp_get_atom(ios->npd_pool, sizeof(IOSNPD));
       node->bound = 0.0;
       node->ii_cnt = 0;
       node->ii_sum = 0.0;
@@ -65,7 +65,7 @@ void ios_attach_rgd(IOS *ios, int i)
 {     IOSRGD *rgd;
       rgd = ios_get_rgd_ptr(ios, i);
       xassert(rgd == NULL);
-      rgd = dmp_get_atom(ios->rgd_pool);
+      rgd = dmp_get_atom(ios->rgd_pool, sizeof(IOSRGD));
       rgd->mark = 0;
       rgd->link = NULL;
       ios_set_rgd_ptr(ios, i, rgd);
@@ -85,7 +85,7 @@ void ios_attach_cgd(IOS *ios, int j)
 {     IOSCGD *cgd;
       cgd = ios_get_cgd_ptr(ios, j);
       xassert(cgd == NULL);
-      cgd = dmp_get_atom(ios->cgd_pool);
+      cgd = dmp_get_atom(ios->cgd_pool, sizeof(IOSCGD));
       cgd->kind = IOS_NUM;
       cgd->mark = 0;
       cgd->link = NULL;
@@ -103,7 +103,7 @@ void ios_attach_row(IOS *ios, int i)
 {     IOSROW *row;
       row = ios_get_row_ptr(ios, i);
       xassert(row == NULL);
-      row = dmp_get_atom(ios->row_pool);
+      row = dmp_get_atom(ios->row_pool, sizeof(IOSROW));
       row->prim = 0.0;
       row->dual = 0.0;
       row->pi = 0.0;
@@ -121,7 +121,7 @@ void ios_attach_col(IOS *ios, int j)
 {     IOSCOL *col;
       col = ios_get_col_ptr(ios, j);
       xassert(col == NULL);
-      col = dmp_get_atom(ios->col_pool);
+      col = dmp_get_atom(ios->col_pool, sizeof(IOSCOL));
       col->prim = 0.0;
       col->dual = 0.0;
       col->frac = 0;
@@ -139,7 +139,7 @@ void ios_detach_row(IOS *ios, int i)
 {     IOSROW *row;
       row = ios_get_row_ptr(ios, i);
       xassert(row != NULL);
-      dmp_free_atom(ios->row_pool, row);
+      dmp_free_atom(ios->row_pool, row, sizeof(IOSROW));
       row = NULL;
       ios_set_row_ptr(ios, i, row);
       return;
@@ -155,7 +155,7 @@ void ios_detach_col(IOS *ios, int j)
 {     IOSCOL *col;
       col = ios_get_col_ptr(ios, j);
       xassert(col != NULL);
-      dmp_free_atom(ios->col_pool, col);
+      dmp_free_atom(ios->col_pool, col, sizeof(IOSCOL));
       col = NULL;
       ios_set_col_ptr(ios, j, col);
       return;
@@ -182,7 +182,7 @@ void ios_hook_routine(void *info, int what, char *name, void *link)
             ios->appl(ios, ios->info);
             ios->event = IOS_V_NONE;
             /* delete extension of the subproblem descriptor */
-            dmp_free_atom(ios->npd_pool, ios->hook_link.npd);
+dmp_free_atom(ios->npd_pool, ios->hook_link.npd, sizeof(IOSNPD));
             ios->hook_name = NULL;
             ios->hook_link.npd = NULL;
             break;
@@ -195,7 +195,7 @@ void ios_hook_routine(void *info, int what, char *name, void *link)
             ios->appl(ios, ios->info);
             ios->event = IOS_V_NONE;
             /* delete extension of the row global descriptor */
-            dmp_free_atom(ios->rgd_pool, ios->hook_link.rgd);
+dmp_free_atom(ios->rgd_pool, ios->hook_link.rgd, sizeof(IOSRGD));
             ios->hook_name = NULL;
             ios->hook_link.rgd = NULL;
             break;
@@ -208,7 +208,7 @@ void ios_hook_routine(void *info, int what, char *name, void *link)
             ios->appl(ios, ios->info);
             ios->event = IOS_V_NONE;
             /* delete extension of the column global descriptor */
-            dmp_free_atom(ios->cgd_pool, ios->hook_link.cgd);
+dmp_free_atom(ios->cgd_pool, ios->hook_link.cgd, sizeof(IOSCGD));
             ios->hook_name = NULL;
             ios->hook_link.cgd = NULL;
             break;
@@ -237,11 +237,11 @@ IOS *ios_create_tree(void (*appl)(IOS *ios, void *info), void *info)
 {     IOS *ios;
       /* create the main data structure */
       ios = xmalloc(sizeof(IOS));
-      ios->npd_pool = dmp_create_pool(sizeof(IOSNPD));
-      ios->rgd_pool = dmp_create_pool(sizeof(IOSRGD));
-      ios->cgd_pool = dmp_create_pool(sizeof(IOSCGD));
-      ios->row_pool = dmp_create_pool(sizeof(IOSROW));
-      ios->col_pool = dmp_create_pool(sizeof(IOSCOL));
+      ios->npd_pool = dmp_create_poolx(sizeof(IOSNPD));
+      ios->rgd_pool = dmp_create_poolx(sizeof(IOSRGD));
+      ios->cgd_pool = dmp_create_poolx(sizeof(IOSCGD));
+      ios->row_pool = dmp_create_poolx(sizeof(IOSROW));
+      ios->col_pool = dmp_create_poolx(sizeof(IOSCOL));
       ios->iet = NULL;
       ios->hook_name = NULL;
       ios->hook_link.npd = NULL;
@@ -457,11 +457,11 @@ void ios_delete_tree(IOS *ios)
       /* delete implicit enumeration tree */
       iet_delete_tree(ios->iet);
       /* now all atoms must return to their memory pools */
-      xassert(ios->npd_pool->count == 0);
-      xassert(ios->rgd_pool->count == 0);
-      xassert(ios->cgd_pool->count == 0);
-      xassert(ios->row_pool->count == 0);
-      xassert(ios->col_pool->count == 0);
+      xassert(dmp_in_use(ios->npd_pool).lo == 0);
+      xassert(dmp_in_use(ios->rgd_pool).lo == 0);
+      xassert(dmp_in_use(ios->cgd_pool).lo == 0);
+      xassert(dmp_in_use(ios->row_pool).lo == 0);
+      xassert(dmp_in_use(ios->col_pool).lo == 0);
       /* free all the memory */
       dmp_delete_pool(ios->npd_pool);
       dmp_delete_pool(ios->rgd_pool);
