@@ -23,9 +23,7 @@
 -- 02110-1301, USA.
 ----------------------------------------------------------------------*/
 
-#include "glpk.h"
 #include "glpapi.h"
-#include "glplib.h"
 #include "glpios.h"
 #define print xprint1
 #define fault xfault1
@@ -515,15 +513,12 @@ int ios_branch_drtom(IOS *ios, int *_next)
          if (ios->msg_lev >= 2)
             print("ios_branch_drtom: numeric instability");
          /* we must not change the basis to attain optimality, so use
-            dirty engineering (don't worry, this is ok :+) */
-#if 0
-         lp->p_stat = LPX_P_FEAS;
-         lp->d_stat = LPX_D_FEAS;
-#else
-         lpx_put_solution(lp, LPX_P_FEAS, LPX_D_FEAS, NULL, NULL, NULL,
-            NULL, NULL, NULL);
+            dirty engineering */
+         {  int p_stat = GLP_FEAS, d_stat = GLP_FEAS;
+            glp_put_solution(lp, 0, &p_stat, &d_stat, NULL, NULL, NULL,
+               NULL, NULL, NULL, NULL);
+         }
          xassert(lpx_is_b_avail(lp));
-#endif
          xassert(lpx_get_status(lp) == LPX_OPT);
       }
       /* determine number of rows and columns */
