@@ -23,9 +23,9 @@
 -- 02110-1301, USA.
 ----------------------------------------------------------------------*/
 
-#include "glpk.h"
 #include "glpipp.h"
-#include "glplib.h"
+#define dmp_create_poolx(size) dmp_create_pool()
+#define dmp_get_atomv dmp_get_atom
 
 /*----------------------------------------------------------------------
 -- ipp_create_wksp - create MIP presolver workspace.
@@ -52,15 +52,15 @@ IPP *ipp_create_wksp(void)
       ipp->orig_nnz = 0;
       ipp->orig_dir = LPX_MIN;
       ipp->ncols = 0;
-      ipp->row_pool = dmp_create_pool(sizeof(IPPROW));
-      ipp->col_pool = dmp_create_pool(sizeof(IPPCOL));
-      ipp->aij_pool = dmp_create_pool(sizeof(IPPAIJ));
+      ipp->row_pool = dmp_create_poolx(sizeof(IPPROW));
+      ipp->col_pool = dmp_create_poolx(sizeof(IPPCOL));
+      ipp->aij_pool = dmp_create_poolx(sizeof(IPPAIJ));
       ipp->row_ptr = NULL;
       ipp->col_ptr = NULL;
       ipp->row_que = NULL;
       ipp->col_que = NULL;
       ipp->c0 = 0.0;
-      ipp->tqe_pool = dmp_create_pool(0);
+      ipp->tqe_pool = dmp_create_poolx(0);
       ipp->tqe_list = NULL;
       ipp->col_stat = NULL;
       ipp->col_mipx = NULL;
@@ -95,7 +95,7 @@ IPPROW *ipp_add_row(IPP *ipp, double lb, double ub)
       /* perform sanity checks */
       xassert(lb <= ub);
       /* create new row */
-      row = dmp_get_atom(ipp->row_pool);
+      row = dmp_get_atom(ipp->row_pool, sizeof(IPPROW));
       row->lb = lb;
       row->ub = ub;
       row->ptr = NULL;
@@ -150,7 +150,7 @@ IPPCOL *ipp_add_col(IPP *ipp, int i_flag, double lb, double ub,
          if (ub != +DBL_MAX) xassert(ub == floor(ub));
       }
       /* create new column */
-      col = dmp_get_atom(ipp->col_pool);
+      col = dmp_get_atom(ipp->col_pool, sizeof(IPPCOL));
       col->j = ++(ipp->ncols);
       col->i_flag = i_flag;
       col->lb = lb;
@@ -197,7 +197,7 @@ IPPCOL *ipp_add_col(IPP *ipp, int i_flag, double lb, double ub,
 IPPAIJ *ipp_add_aij(IPP *ipp, IPPROW *row, IPPCOL *col, double val)
 {     IPPAIJ *aij;
       xassert(val != 0.0);
-      aij = dmp_get_atom(ipp->aij_pool);
+      aij = dmp_get_atom(ipp->aij_pool, sizeof(IPPAIJ));
       aij->row = row;
       aij->col = col;
       aij->val = val;
@@ -244,7 +244,7 @@ void ipp_remove_row(IPP *ipp, IPPROW *row)
          else
             aij->c_next->c_prev = aij->c_prev;
          /* and return it to its pool */
-         dmp_free_atom(ipp->aij_pool, aij);
+         dmp_free_atom(ipp->aij_pool, aij, sizeof(IPPAIJ));
       }
       /* remove the row from the linked list */
       if (row->prev == NULL)
@@ -256,7 +256,7 @@ void ipp_remove_row(IPP *ipp, IPPROW *row)
       else
          row->next->prev = row->prev;
       /* and return the row to its pool */
-      dmp_free_atom(ipp->row_pool, row);
+      dmp_free_atom(ipp->row_pool, row, sizeof(IPPROW));
       return;
 }
 
@@ -293,7 +293,7 @@ void ipp_remove_col(IPP *ipp, IPPCOL *col)
          else
             aij->r_next->r_prev = aij->r_prev;
          /* and return it to its pool */
-         dmp_free_atom(ipp->aij_pool, aij);
+         dmp_free_atom(ipp->aij_pool, aij, sizeof(IPPAIJ));
       }
       /* remove the column from the linked list */
       if (col->prev == NULL)
@@ -305,7 +305,7 @@ void ipp_remove_col(IPP *ipp, IPPCOL *col)
       else
          col->next->prev = col->prev;
       /* and return the column to its pool */
-      dmp_free_atom(ipp->col_pool, col);
+      dmp_free_atom(ipp->col_pool, col, sizeof(IPPCOL));
       return;
 }
 
