@@ -24,8 +24,8 @@
 ----------------------------------------------------------------------*/
 
 #include "glpipp.h"
-#include "glplib.h"
 #define print xprint1
+#define dmp_get_atomv dmp_get_atom
 
 /*----------------------------------------------------------------------
 -- FREE ROW
