@@ -179,7 +179,7 @@ uldiv_t uldiv(ulong_t x, ulong_t y)
       else if (yy[0])
          m = 1;
       else
-         xfault("uldiv: divide by zero");
+         xfault("uldiv: divide by zero\n");
       bigdiv(4 - m, m, xx, yy);
       /* remainder in x[0], x[1], ..., x[m-1] */
       qr.rem.lo = (unsigned int)xx[0], qr.rem.hi = 0;
@@ -194,4 +194,100 @@ uldiv_t uldiv(ulong_t x, ulong_t y)
       return qr;
 }
 
+/***********************************************************************
+*  NAME
+*
+*  ultoa - convert unsigned long integer to character string
+*
+*  SYNOPSIS
+*
+*  #include "glplib.h"
+*  char *ultoa(ulong_t x, char *s, int radix);
+*
+*  DESCRIPTION
+*
+*  The routine ultoa converts the value unsigned long integer x to a
+*  null-terminated character string and stores the result in s.
+*
+*  The parameter radix specifies the base to be used on converting. It
+*  must be between 2 and 36, inclusive.
+*
+*  NOTE
+*
+*  The space allocated to s must be sufficient to hold the resulting
+*  string, includeing the terminating null character.
+*
+*  RETURNS
+*
+*  The routine returns the pointer s. */
+
+char *ultoa(ulong_t x, char *s, int radix)
+{     static const char *d = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ";
+      ulong_t base;
+      uldiv_t t;
+      int len = 0;
+      xassert(2 <= radix && radix <= 36);
+      base = ulset(0, radix);
+      while (!(x.lo == 0 && x.hi == 0))
+      {  t = uldiv(x, base);
+         xassert(t.rem.lo < (unsigned int)radix && t.rem.hi == 0);
+         s[len++] = d[t.rem.lo];
+         x = t.quot;
+      }
+      if (len == 0) s[len++] = '0';
+      s[len] = '\0';
+      return strrev(s);
+}
+
+/**********************************************************************/
+
+#if 0
+#include <assert.h>
+#include "glprng.h"
+
+#define N_TEST 1000000
+/* number of tests */
+
+static ulong_t random(RNG *rand)
+{     ulong_t x;
+      int k;
+      k = rng_unif_rand(rand, 4);
+      assert(0 <= k && k <= 3);
+      x.lo = rng_unif_rand(rand, 65536);
+      if (k == 1 || k == 3)
+      {  x.lo <<= 16;
+         x.lo += rng_unif_rand(rand, 65536);
+      }
+      if (k <= 1)
+         x.hi = 0;
+      else
+         x.hi = rng_unif_rand(rand, 65536);
+      if (k == 4)
+      {  x.hi <<= 16;
+         x.hi += rng_unif_rand(rand, 65536);
+      }
+      return x;
+}
+
+int main(void)
+{     RNG *rand;
+      ulong_t x, y;
+      uldiv_t z;
+      int test;
+      rand = rng_create_rand();
+      for (test = 1; test <= N_TEST; test++)
+      {  x = random(rand);
+         y = random(rand);
+         if (y.lo == 0 && y.hi == 0) y.lo = 1;
+         /* z.quot := x div y, z.rem := x mod y */
+         z = uldiv(x, y);
+         /* x must be equal to y * z.quot + z.rem */
+         assert(ulcmp(x, uladd(ulmul(y, z.quot), z.rem)) == 0);
+      }
+      fprintf(stderr, "%d tests successfully passed\n", N_TEST);
+      rng_delete_rand(rand);
+      return 0;
+}
+#endif
+
 /* eof */
