@@ -23,6 +23,7 @@
 *  02110-1301, USA.
 ***********************************************************************/
 
+#define _GLPLIB_PRIVATE
 #include "glplib.h"
 
 /***********************************************************************
@@ -152,4 +153,67 @@ void xfree(void *ptr)
       return;
 }
 
+/***********************************************************************
+*  NAME
+*
+*  lib_mem_limit - set memory allocation limit
+*
+*  SYNOPSIS
+*
+*  #include "glplib.h"
+*  void lib_mem_limit(ulong_t limit);
+*
+*  DESCRIPTION
+*
+*  The routine lib_mem_limit limits the amount of memory available for
+*  dynamic allocation (in GLPK routines) to limit bytes. */
+
+void lib_mem_limit(ulong_t limit)
+{     LIBENV *env = lib_link_env();
+      env->mem_limit = limit;
+      return;
+}
+
+/***********************************************************************
+*  NAME
+*
+*  lib_mem_usage - get memory usage information
+*
+*  SYNOPSIS
+*
+*  #include "glplib.h"
+*  void lib_mem_usage(int *count, int *cpeak, ulong_t *total,
+*     ulong_t *tpeak);
+*
+*  DESCRIPTION
+*
+*  The routine lib_mem_usage reports some information about utilization
+*  of the memory by GLPK routines. Information is stored to locations
+*  specified by corresponding parameters (see below). Any parameter can
+*  be specified as NULL, in which case corresponding information is not
+*  stored.
+*
+*  *count is the number of the memory blocks currently allocated by the
+*  routines xmalloc and xcalloc (one call to xmalloc or xcalloc results
+*  in allocating one memory block).
+*
+*  *cpeak is the peak value of *count reached since the initialization
+*  of the GLPK library environment.
+*
+*  *total is the total amount, in bytes, of the memory blocks currently
+*  allocated by the routines xmalloc and xcalloc.
+*
+*  *tpeak is the peak value of *total reached since the initialization
+*  of the GLPK library envirionment. */
+
+void lib_mem_usage(int *count, int *cpeak, ulong_t *total,
+      ulong_t *tpeak)
+{     LIBENV *env = lib_link_env();
+      if (count != NULL) *count = env->mem_count;
+      if (cpeak != NULL) *cpeak = env->mem_cpeak;
+      if (total != NULL) *total = env->mem_total;
+      if (tpeak != NULL) *tpeak = env->mem_tpeak;
+      return;
+}
+
 /* eof */
