@@ -24,8 +24,9 @@
 ----------------------------------------------------------------------*/
 
 #include "glpk.h"
-#include "glplib.h"
 #include "glplpp.h"
+#define dmp_create_poolx(size) dmp_create_pool()
+#define dmp_get_atomv dmp_get_atom
 
 /*----------------------------------------------------------------------
 -- lpp_create_wksp - create LP presolver workspace.
@@ -53,15 +54,15 @@ LPP *lpp_create_wksp(void)
       lpp->orig_dir = LPX_MIN;
       lpp->nrows = 0;
       lpp->ncols = 0;
-      lpp->row_pool = dmp_create_pool(sizeof(LPPROW));
-      lpp->col_pool = dmp_create_pool(sizeof(LPPCOL));
-      lpp->aij_pool = dmp_create_pool(sizeof(LPPAIJ));
+      lpp->row_pool = dmp_create_poolx(sizeof(LPPROW));
+      lpp->col_pool = dmp_create_poolx(sizeof(LPPCOL));
+      lpp->aij_pool = dmp_create_poolx(sizeof(LPPAIJ));
       lpp->row_ptr = NULL;
       lpp->col_ptr = NULL;
       lpp->row_que = NULL;
       lpp->col_que = NULL;
       lpp->c0 = 0.0;
-      lpp->tqe_pool = dmp_create_pool(0);
+      lpp->tqe_pool = dmp_create_poolx(0);
       lpp->tqe_list = NULL;
       lpp->m = 0;
       lpp->n = 0;
@@ -102,7 +103,7 @@ LPP *lpp_create_wksp(void)
 
 LPPROW *lpp_add_row(LPP *lpp, double lb, double ub)
 {     LPPROW *row;
-      row = dmp_get_atom(lpp->row_pool);
+      row = dmp_get_atom(lpp->row_pool, sizeof(LPPROW));
       row->i = ++(lpp->nrows);
       row->lb = lb;
       row->ub = ub;
@@ -145,7 +146,7 @@ LPPROW *lpp_add_row(LPP *lpp, double lb, double ub)
 
 LPPCOL *lpp_add_col(LPP *lpp, double lb, double ub, double c)
 {     LPPCOL *col;
-      col = dmp_get_atom(lpp->col_pool);
+      col = dmp_get_atom(lpp->col_pool, sizeof(LPPCOL));
       col->j = ++(lpp->ncols);
       col->lb = lb;
       col->ub = ub;
@@ -189,7 +190,7 @@ LPPCOL *lpp_add_col(LPP *lpp, double lb, double ub, double c)
 LPPAIJ *lpp_add_aij(LPP *lpp, LPPROW *row, LPPCOL *col, double val)
 {     LPPAIJ *aij;
       xassert(val != 0.0);
-      aij = dmp_get_atom(lpp->aij_pool);
+      aij = dmp_get_atom(lpp->aij_pool, sizeof(LPPAIJ));
       aij->row = row;
       aij->col = col;
       aij->val = val;
@@ -238,7 +239,7 @@ void lpp_remove_row(LPP *lpp, LPPROW *row)
          else
             aij->c_next->c_prev = aij->c_prev;
          /* and return it to its pool */
-         dmp_free_atom(lpp->aij_pool, aij);
+         dmp_free_atom(lpp->aij_pool, aij, sizeof(LPPAIJ));
       }
       /* remove the row from the linked list */
       if (row->prev == NULL)
@@ -250,7 +251,7 @@ void lpp_remove_row(LPP *lpp, LPPROW *row)
       else
          row->next->prev = row->prev;
       /* and return the row to its pool */
-      dmp_free_atom(lpp->row_pool, row);
+      dmp_free_atom(lpp->row_pool, row, sizeof(LPPROW));
       return;
 }
 
@@ -289,7 +290,7 @@ void lpp_remove_col(LPP *lpp, LPPCOL *col)
          else
             aij->r_next->r_prev = aij->r_prev;
          /* and return it to its pool */
-         dmp_free_atom(lpp->aij_pool, aij);
+         dmp_free_atom(lpp->aij_pool, aij, sizeof(LPPAIJ));
       }
       /* remove the column from the linked list */
       if (col->prev == NULL)
@@ -301,7 +302,7 @@ void lpp_remove_col(LPP *lpp, LPPCOL *col)
       else
          col->next->prev = col->prev;
       /* and return the column to its pool */
-      dmp_free_atom(lpp->col_pool, col);
+      dmp_free_atom(lpp->col_pool, col, sizeof(LPPCOL));
       return;
 }
 
@@ -757,7 +758,8 @@ void lpp_load_sol(LPP *lpp, LPX *prob)
 -- the parameter orig points to. */
 
 void lpp_unload_sol(LPP *lpp, LPX *orig)
-{     int i, j, k, m, n, typx, tagx;
+{     int i, j, k, m, n, typx, tagx, p_stat, d_stat;
+      double sum;
       m = lpp->orig_m;
       n = lpp->orig_n;
       xassert(m == lpx_get_num_rows(orig));
@@ -802,12 +804,21 @@ void lpp_unload_sol(LPP *lpp, LPX *orig)
       }
       /* store solution components into the original problem object (it
          is assumed that the recovered solution is optimal) */
-#if 1
-      lpx_put_lp_basis(orig, LPX_B_UNDEF, NULL, lpx_access_inv(orig));
-#endif
-      lpx_put_solution(orig, LPX_P_FEAS, LPX_D_FEAS,
+      p_stat = d_stat = GLP_FEAS;
+      for (i = 1; i <= m; i++)
+         lpp->row_stat[i] = lpp->row_stat[i] - LPX_BS + GLP_BS;
+      for (j = 1; j <= n; j++)
+         lpp->col_stat[j] = lpp->col_stat[j] - LPX_BS + GLP_BS;
+      sum = lpx_get_obj_coef(orig, 0);
+      for (j = 1; j <= n; j++)
+         sum += lpx_get_obj_coef(orig, j) * lpp->col_prim[j];
+      glp_put_solution(orig, 1, &p_stat, &d_stat, &sum,
          lpp->row_stat, lpp->row_prim, lpp->row_dual,
          lpp->col_stat, lpp->col_prim, lpp->col_dual);
+      for (i = 1; i <= m; i++)
+         lpp->row_stat[i] = lpp->row_stat[i] - GLP_BS + LPX_BS;
+      for (j = 1; j <= n; j++)
+         lpp->col_stat[j] = lpp->col_stat[j] - GLP_BS + LPX_BS;
       return;
 }
 
