@@ -24,8 +24,8 @@
 ----------------------------------------------------------------------*/
 
 #include "glpk.h"
-#include "glplib.h"
 #include "glplpp.h"
+#define dmp_get_atomv dmp_get_atom
 
 /*----------------------------------------------------------------------
 -- EMPTY ROW
@@ -1346,7 +1346,7 @@ static void process_forcing_row(LPP *lpp, LPPROW *row, int at)
          /* remove it from the row list */
          row->ptr = aij->r_next;
          /* and return it to its pool */
-         dmp_free_atom(lpp->aij_pool, aij);
+         dmp_free_atom(lpp->aij_pool, aij, sizeof(LPPAIJ));
       }
       /* physically remove the row p (now it is empty) */
       lpp_remove_row(lpp, row);
