@@ -101,7 +101,7 @@ static int simplex1(LPX *lpx)
 {     /* base driver which does not use LP presolver */
       SPX _spx, *spx = &_spx;
       int i, j, k, m, n, t, nnz, typx, tagx, pos, ret;
-      double rii, sjj, lb, ub, *prim, *dual;
+      double rii, sjj, lb, ub, *prim, *dual, sum;
       spx->m = m = lpx_get_num_rows(lpx);
       spx->n = n = lpx_get_num_cols(lpx);
       spx->typx = xcalloc(1+m+n, sizeof(int));
@@ -237,10 +237,17 @@ static int simplex1(LPX *lpx)
             dual[k] /= lpx_get_sjj(lpx, k-m);
          }
       }
-      lpx_put_solution(lpx, spx->p_stat, spx->d_stat,
+      spx->p_stat = spx->p_stat - LPX_P_UNDEF + GLP_UNDEF;
+      spx->d_stat = spx->d_stat - LPX_D_UNDEF + GLP_UNDEF;
+      for (k = 1; k <= m+n; k++)
+         spx->tagx[k] = spx->tagx[k] - LPX_BS + GLP_BS;
+      sum = lpx_get_obj_coef(lpx, 0);
+      for (j = 1; j <= n; j++)
+         sum += lpx_get_obj_coef(lpx, j) * prim[m+j];
+      glp_put_solution(lpx, 0, &spx->p_stat, &spx->d_stat, &sum,
          &spx->tagx[0], &prim[0], &dual[0],
          &spx->tagx[m], &prim[m], &dual[m]);
-      if (spx->p_stat == LPX_P_FEAS && spx->d_stat == LPX_D_NOFEAS)
+      if (spx->p_stat == GLP_FEAS && spx->d_stat == GLP_NOFEAS)
          lpx_put_ray_info(lpx, spx->some);
       else
          lpx_put_ray_info(lpx, 0);
@@ -361,6 +368,8 @@ static int simplex2(LPX *orig)
       /* inherit some control parameters from the original object */
       lpx_set_int_parm(prob, LPX_K_MSGLEV, lpx_get_int_parm(orig,
          LPX_K_MSGLEV));
+      lpx_set_int_parm(prob, LPX_K_BFTYPE, lpx_get_int_parm(orig,
+         LPX_K_BFTYPE));
       lpx_set_int_parm(prob, LPX_K_SCALE, lpx_get_int_parm(orig,
          LPX_K_SCALE));
       lpx_set_int_parm(prob, LPX_K_DUAL, lpx_get_int_parm(orig,
@@ -436,8 +445,8 @@ post: /* perform LP postsolve processing */
 
 static void triv_problem1(LPX *lp)
 {     /* solve trivial problem which has no rows */
-      int n, j, d_stat, *col_stat;
-      double dir, *col_prim, *col_dual;
+      int n, j, p_stat, d_stat, *col_stat;
+      double dir, *col_prim, *col_dual, sum;
       xassert(lpx_get_num_rows(lp) == 0);
       n = lpx_get_num_cols(lp);
       col_stat = xcalloc(1+n, sizeof(int));
@@ -486,11 +495,15 @@ up:            col_stat[j] = LPX_NU;
                xassert(lp != lp);
          }
       }
-#if 1
-      lpx_put_lp_basis(lp, LPX_B_UNDEF, NULL, lpx_access_inv(lp));
-#endif
-      lpx_put_solution(lp, LPX_P_FEAS, d_stat, NULL, NULL, NULL,
-         col_stat, col_prim, col_dual);
+      p_stat = GLP_FEAS;
+      d_stat = d_stat - LPX_D_UNDEF + GLP_UNDEF;
+      sum = lpx_get_obj_coef(lp, 0);
+      for (j = 1; j <= n; j++)
+      {  sum += lpx_get_obj_coef(lp, j) * col_prim[j];
+         col_stat[j] = col_stat[j] - LPX_BS + GLP_BS;
+      }
+      glp_put_solution(lp, 1, &p_stat, &d_stat, &sum,
+         NULL, NULL, NULL, col_stat, col_prim, col_dual);
       xfree(col_stat);
       xfree(col_prim);
       xfree(col_dual);
@@ -500,7 +513,7 @@ up:            col_stat[j] = LPX_NU;
             lpx_get_int_parm(lp, LPX_K_ITCNT), lpx_get_obj_val(lp), 0.0)
             ;
          if (lpx_get_int_parm(lp, LPX_K_MSGLEV) >= 3)
-         {  if (d_stat == LPX_D_FEAS)
+         {  if (d_stat == GLP_FEAS)
                print("OPTIMAL SOLUTION FOUND");
             else
                print("PROBLEM HAS UNBOUNDED SOLUTION");
@@ -511,7 +524,7 @@ up:            col_stat[j] = LPX_NU;
 
 static void triv_problem2(LPX *lp)
 {     /* solve trivial problem which has no columns */
-      int m, i, p_stat, *row_stat;
+      int m, i, p_stat, d_stat, *row_stat;
       double lb, ub, sum, *row_prim, *row_dual;
       xassert(lpx_get_num_cols(lp) == 0);
       m = lpx_get_num_rows(lp);
@@ -544,11 +557,13 @@ static void triv_problem2(LPX *lp)
                xassert(lp != lp);
          }
       }
-#if 1
-      lpx_put_lp_basis(lp, LPX_B_UNDEF, NULL, lpx_access_inv(lp));
-#endif
-      lpx_put_solution(lp, p_stat, LPX_D_FEAS, row_stat, row_prim,
-         row_dual, NULL, NULL, NULL);
+      p_stat = p_stat - LPX_P_UNDEF + GLP_UNDEF;
+      d_stat = GLP_FEAS;
+      for (i = 1; i <= m; i++)
+         row_stat[i] = row_stat[i] - LPX_BS + GLP_BS;
+      sum = glp_get_obj_coef(lp, 0);
+      glp_put_solution(lp, 1, &p_stat, &d_stat, &sum,
+         row_stat, row_prim, row_dual, NULL, NULL, NULL);
       xfree(row_stat);
       xfree(row_prim);
       xfree(row_dual);
@@ -558,7 +573,7 @@ static void triv_problem2(LPX *lp)
             lpx_get_int_parm(lp, LPX_K_ITCNT), lpx_get_obj_val(lp), sum)
             ;
          if (lpx_get_int_parm(lp, LPX_K_MSGLEV) >= 3)
-         {  if (p_stat == LPX_P_FEAS)
+         {  if (p_stat == GLP_FEAS)
                print("OPTIMAL SOLUTION FOUND");
             else
                print("PROBLEM HAS NO FEASIBLE SOLUTION");
