@@ -512,12 +512,14 @@ int lpx_intopt(LPX *_mip)
 {     IPP *ipp = NULL;
       LPX *orig = _mip, *prob = NULL;
       int orig_m, orig_n, i, j, ret, i_stat, use_cuts;
+#if 0
       /* the problem must be of MIP class */
       if (lpx_get_class(orig) != LPX_MIP)
       {  print("lpx_intopt: problem is not of MIP class");
          ret = LPX_E_FAULT;
          goto done;
       }
+#endif
       /* the problem must have at least one row and one column */
       orig_m = lpx_get_num_rows(orig);
       orig_n = lpx_get_num_cols(orig);
@@ -659,6 +661,8 @@ nodfs:      print("LP RELAXATION HAS NO DUAL FEASIBLE SOLUTION");
             ni, ni == 1 ? "" : "s", s, nb == 1 ? "is" : "are");
       }
       /* inherit some control parameters and statistics */
+      lpx_set_int_parm(prob, LPX_K_BFTYPE, lpx_get_int_parm(orig,
+         LPX_K_BFTYPE));
       lpx_set_int_parm(prob, LPX_K_PRICE, lpx_get_int_parm(orig,
          LPX_K_PRICE));
       lpx_set_real_parm(prob, LPX_K_RELAX, lpx_get_real_parm(orig,
