@@ -24,7 +24,6 @@
 ----------------------------------------------------------------------*/
 
 #include "glpapi.h"
-#include "glpk.h"
 #include "glplib.h"
 #define fault xfault1
 
@@ -134,7 +133,7 @@ int lpx_invert(LPX *lp)
       }
       info.lp = lp;
       info.basis = basis;
-      ret = bfi_factorize(b_inv, m, &info, basic_column);
+      ret = bfi_factorize(b_inv, m, basic_column, &info);
       xassert(ret == 0 || ret == 1 || ret == 2);
 fini: /* put the basis back to the problem object */
       lpx_put_lp_basis(lp, (ret == 0 ? LPX_B_VALID : LPX_B_UNDEF),
@@ -211,7 +210,7 @@ void lpx_ftran(LPX *lp, double x[])
       }
       /* solve the system B"*x" = b" */
       b_inv = lpx_access_inv(lp);
-      bfi_ftran_dense(b_inv, x, 0);
+      bfi_ftran(b_inv, x, 0);
       /* compute x = SB*x" */
       for (i = 1; i <= m; i++)
       {  if (x[i] == 0.0) continue;
@@ -267,7 +266,7 @@ void lpx_btran(LPX *lp, double x[])
       }
       /* solve the system (B")'*x" = b" */
       b_inv = lpx_access_inv(lp);
-      bfi_btran_dense(b_inv, x);
+      bfi_btran(b_inv, x);
       /* compute x = R*x" */
       for (i = 1; i <= m; i++)
       {  if (x[i] == 0.0) continue;
@@ -521,9 +520,9 @@ void lpx_eval_b_dual(LPX *lp, double row_dual[], double col_dual[])
 -- LPX_E_SING     the basis matrix is singular or ill-conditioned. */
 
 int lpx_warm_up(LPX *lp)
-{     int m, n, k, ret, type, stat, p_stat, d_stat;
+{     int m, n, j, k, ret, type, stat, p_stat, d_stat;
       double lb, ub, prim, dual, tol_bnd, tol_dj, dir;
-      double *row_prim, *row_dual, *col_prim, *col_dual;
+      double *row_prim, *row_dual, *col_prim, *col_dual, sum;
       m = lpx_get_num_rows(lp);
       n = lpx_get_num_cols(lp);
       /* reinvert the basis matrix, if necessary */
@@ -621,11 +620,14 @@ int lpx_warm_up(LPX *lp)
          }
       }
       /* store basic solution components */
-#if 1
+      p_stat = p_stat - LPX_P_UNDEF + GLP_UNDEF;
+      d_stat = d_stat - LPX_D_UNDEF + GLP_UNDEF;
+      sum = lpx_get_obj_coef(lp, 0);
+      for (j = 1; j <= n; j++)
+         sum += lpx_get_obj_coef(lp, j) * col_prim[j];
+      glp_put_solution(lp, 0, &p_stat, &d_stat, &sum,
+         NULL, row_prim, row_dual, NULL, col_prim, col_dual);
       xassert(lpx_is_b_avail(lp));
-#endif
-      lpx_put_solution(lp, p_stat, d_stat, NULL, row_prim, row_dual,
-         NULL, col_prim, col_dual);
       /* free working arrays */
       xfree(row_prim);
       xfree(row_dual);
