@@ -23,9 +23,9 @@
 -- 02110-1301, USA.
 ----------------------------------------------------------------------*/
 
-#include "glplib.h"
 #include "glplux.h"
 #define fault xfault1
+#define dmp_create_poolx(size) dmp_create_pool()
 
 /*----------------------------------------------------------------------
 // lux_create - create LU-factorization.
@@ -53,7 +53,7 @@ LUX *lux_create(int n)
          fault("lux_create: n = %d; invalid parameter", n);
       lux = xmalloc(sizeof(LUX));
       lux->n = n;
-      lux->pool = dmp_create_pool(sizeof(LUXELM));
+      lux->pool = dmp_create_poolx(sizeof(LUXELM));
       lux->F_row = xcalloc(1+n, sizeof(LUXELM *));
       lux->F_col = xcalloc(1+n, sizeof(LUXELM *));
       lux->V_piv = xcalloc(1+n, sizeof(mpq_t));
@@ -112,7 +112,7 @@ static void initialize(LUX *lux, int (*col)(void *info, int j,
       {  while (F_row[i] != NULL)
          {  fij = F_row[i], F_row[i] = fij->r_next;
             mpq_clear(fij->val);
-            dmp_free_atom(pool, fij);
+            dmp_free_atom(pool, fij, sizeof(LUXELM));
          }
       }
       for (j = 1; j <= n; j++) F_col[j] = NULL;
@@ -122,7 +122,7 @@ static void initialize(LUX *lux, int (*col)(void *info, int j,
       {  while (V_row[i] != NULL)
          {  vij = V_row[i], V_row[i] = vij->r_next;
             mpq_clear(vij->val);
-            dmp_free_atom(pool, vij);
+            dmp_free_atom(pool, vij, sizeof(LUXELM));
          }
       }
       for (j = 1; j <= n; j++) V_col[j] = NULL;
@@ -152,7 +152,7 @@ static void initialize(LUX *lux, int (*col)(void *info, int j,
                fault("lux_decomp: j = %d: i = %d; zero elements not all"
                   "owed", j, i);
             /* add new element v[i,j] = a[i,j] to V */
-            vij = dmp_get_atom(pool);
+            vij = dmp_get_atom(pool, sizeof(LUXELM));
             vij->i = i, vij->j = j;
             mpq_init(vij->val);
             mpq_set(vij->val, val[k]);
@@ -482,7 +482,7 @@ static void eliminate(LUX *lux, LUXWKA *wka, LUXELM *piv, int flag[],
       C_len[q]--;
       /* free the space occupied by the pivot */
       mpq_clear(piv->val);
-      dmp_free_atom(pool, piv);
+      dmp_free_atom(pool, piv, sizeof(LUXELM));
       /* walk through p-th (pivot) row, which already does not contain
          the pivot v[p,q], and do the following... */
       for (vpj = V_row[p]; vpj != NULL; vpj = vpj->r_next)
@@ -532,7 +532,7 @@ static void eliminate(LUX *lux, LUXWKA *wka, LUXELM *piv, int flag[],
             R_prev[R_next[i]] = R_prev[i];
          /* compute gaussian multiplier f[i,p] = v[i,q] / v[p,q] and
             store it in the matrix F */
-         fip = dmp_get_atom(pool);
+         fip = dmp_get_atom(pool, sizeof(LUXELM));
          fip->i = i, fip->j = p;
          mpq_init(fip->val);
          mpq_div(fip->val, viq->val, V_piv[p]);
@@ -558,7 +558,7 @@ static void eliminate(LUX *lux, LUXWKA *wka, LUXELM *piv, int flag[],
          C_len[q]--;
          /* free the space occupied by v[i,q] */
          mpq_clear(viq->val);
-         dmp_free_atom(pool, viq);
+         dmp_free_atom(pool, viq, sizeof(LUXELM));
          /* perform gaussian transformation:
             (i-th row) := (i-th row) - f[i,p] * (p-th row)
             note that now p-th row, which is in the working array,
@@ -601,7 +601,7 @@ static void eliminate(LUX *lux, LUXWKA *wka, LUXELM *piv, int flag[],
                   C_len[j]--;
                   /* free the space occupied by v[i,j] */
                   mpq_clear(vij->val);
-                  dmp_free_atom(pool, vij);
+                  dmp_free_atom(pool, vij, sizeof(LUXELM));
                }
             }
          }
@@ -613,7 +613,7 @@ static void eliminate(LUX *lux, LUXWKA *wka, LUXELM *piv, int flag[],
             if (flag[j])
             {  /* create new non-zero v[i,j] = 0 - f[i,p] * v[p,j] and
                   add it to i-th row and j-th column */
-               vij = dmp_get_atom(pool);
+               vij = dmp_get_atom(pool, sizeof(LUXELM));
                vij->i = i, vij->j = j;
                mpq_init(vij->val);
                mpq_mul(vij->val, fip->val, work[j]);
