@@ -24,9 +24,9 @@
 ----------------------------------------------------------------------*/
 
 #include "glpk.h"
-#include "glplib.h"
 #include "glpmip.h"
 #define fault xfault1
+#define dmp_create_poolx(size) dmp_create_pool()
 
 /*----------------------------------------------------------------------
 -- mip_create_tree - create branch-and-bound tree.
@@ -69,9 +69,9 @@ MIPTREE *mip_create_tree(int m, int n, int dir)
       tree->dir = dir;
       tree->int_obj = 0;
       tree->int_col = xcalloc(1+n, sizeof(int));
-      tree->node_pool = dmp_create_pool(sizeof(MIPNODE));
-      tree->bnds_pool = dmp_create_pool(sizeof(MIPBNDS));
-      tree->stat_pool = dmp_create_pool(sizeof(MIPSTAT));
+      tree->node_pool = dmp_create_poolx(sizeof(MIPNODE));
+      tree->bnds_pool = dmp_create_poolx(sizeof(MIPBNDS));
+      tree->stat_pool = dmp_create_poolx(sizeof(MIPSTAT));
       tree->nslots = 20;
       tree->avail = 0;
       tree->slot = xcalloc(1+tree->nslots, sizeof(MIPSLOT));
@@ -115,7 +115,8 @@ MIPTREE *mip_create_tree(int m, int n, int dir)
       xassert(tree->slot[p].node == NULL);
       tree->slot[p].next = 0;
       /* create and initialize the root subproblem */
-      tree->slot[p].node = node = dmp_get_atom(tree->node_pool);
+      tree->slot[p].node = node =
+         dmp_get_atom(tree->node_pool, sizeof(MIPNODE));
       node->p = p;
       node->up = NULL;
       node->level = 0;
@@ -243,13 +244,13 @@ err:     fault("mip_revive_node: p = %d; invalid subproblem reference n"
       while (node->bnds != NULL)
       {  bnds = node->bnds;
          node->bnds = bnds->next;
-         dmp_free_atom(tree->bnds_pool, bnds);
+         dmp_free_atom(tree->bnds_pool, bnds, sizeof(MIPBNDS));
       }
       /* delete the statuses change list */
       while (node->stat != NULL)
       {  stat = node->stat;
          node->stat = stat->next;
-         dmp_free_atom(tree->stat_pool, stat);
+         dmp_free_atom(tree->stat_pool, stat, sizeof(MIPSTAT));
       }
       return;
 }
@@ -298,7 +299,7 @@ void mip_freeze_node(MIPTREE *tree)
          /* save type and bounds of row/column, if changed */
          if (!(tree->old_type[k] == type && tree->old_lb[k] == lb &&
                tree->old_ub[k] == ub))
-         {  bnds = dmp_get_atom(tree->bnds_pool);
+         {  bnds = dmp_get_atom(tree->bnds_pool, sizeof(MIPBNDS));
             bnds->k = k;
             bnds->type = type;
             bnds->lb = lb;
@@ -308,7 +309,7 @@ void mip_freeze_node(MIPTREE *tree)
          }
          /* save status of row/column, if changed */
          if (tree->old_stat[k] != stat)
-         {  ssss = dmp_get_atom(tree->stat_pool);
+         {  ssss = dmp_get_atom(tree->stat_pool, sizeof(MIPSTAT));
             ssss->k = k;
             ssss->stat = stat;
             ssss->next = node->stat;
@@ -403,7 +404,8 @@ err:     fault("mip_clone_node: p = %d; invalid subproblem reference nu"
          xassert(tree->slot[p].node == NULL);
          tree->slot[p].next = 0;
          /* create descriptor for new subproblem */
-         tree->slot[p].node = node = dmp_get_atom(tree->node_pool);
+         tree->slot[p].node = node =
+            dmp_get_atom(tree->node_pool, sizeof(MIPNODE));
          node->p = p;
          node->up = orig;
          node->level = orig->level + 1;
@@ -484,13 +486,13 @@ loop: /* recursive deletion starts here */
       while (node->bnds != NULL)
       {  bnds = node->bnds;
          node->bnds = bnds->next;
-         dmp_free_atom(tree->bnds_pool, bnds);
+         dmp_free_atom(tree->bnds_pool, bnds, sizeof(MIPBNDS));
       }
       /* delete the statuses change list */
       while (node->stat != NULL)
       {  stat = node->stat;
          node->stat = stat->next;
-         dmp_free_atom(tree->stat_pool, stat);
+         dmp_free_atom(tree->stat_pool, stat, sizeof(MIPSTAT));
       }
       /* free the corresponding node slot */
       p = node->p;
@@ -501,7 +503,7 @@ loop: /* recursive deletion starts here */
       /* save pointer to the parent subproblem */
       temp = node->up;
       /* delete the subproblem descriptor */
-      dmp_free_atom(tree->node_pool, node);
+      dmp_free_atom(tree->node_pool, node, sizeof(MIPNODE));
       tree->n_cnt--;
       /* take pointer to the parent subproblem */
       node = temp;
