@@ -24,7 +24,6 @@
 ----------------------------------------------------------------------*/
 
 #include "glpk.h"
-#include "glplib.h"
 #include "glpmip.h"
 #define print xprint1
 
@@ -371,12 +370,9 @@ static void fix_by_red_cost(MIPTREE *tree)
          else
             print("%d columns have been fixed by reduced costs", fixed);
       }
-      /* fixing non-basic columns on their current bounds does not
-         change the basic solution itself, however, lpx_set_col_bnds
-         resets the primal and dual statuses to undefined state, and
-         therefore we need to restore them */
-      lpx_put_solution(lp, LPX_P_FEAS, LPX_D_FEAS, NULL, NULL, NULL,
-         NULL, NULL, NULL);
+      /* fixing non-basic columns on their current bounds must not
+         change the basic solution */
+      xassert(lpx_get_status(lp) == LPX_OPT);
       return;
 }
 
@@ -1072,9 +1068,9 @@ fath: /* the current subproblem has been fathomed */
       if (tree->head == NULL)
       {  if (tree->msg_lev >= 3)
             print("Active list is empty!");
-         xassert(tree->node_pool->count == 0);
-         xassert(tree->bnds_pool->count == 0);
-         xassert(tree->stat_pool->count == 0);
+         xassert(dmp_in_use(tree->node_pool).lo == 0);
+         xassert(dmp_in_use(tree->bnds_pool).lo == 0);
+         xassert(dmp_in_use(tree->stat_pool).lo == 0);
          ret = MIP_E_OK;
          goto done;
       }
