@@ -55,7 +55,7 @@ SLICE *expand_slice
 )
 {     SLICE *tail, *temp;
       /* create a new component */
-      tail = dmp_get_atom(mpl->tuples);
+      tail = dmp_get_atom(mpl->tuples, sizeof(SLICE));
       tail->sym = sym;
       tail->next = NULL;
       /* and append it to the component list */
@@ -132,7 +132,8 @@ void delete_slice
       {  temp = slice;
          slice = temp->next;
          if (temp->sym != NULL) delete_symbol(mpl, temp->sym);
-         dmp_free_atom(mpl->tuples, temp);
+xassert(sizeof(SLICE) == sizeof(TUPLE));
+         dmp_free_atom(mpl->tuples, temp, sizeof(TUPLE));
       }
       return;
 }
@@ -297,10 +298,10 @@ SET *select_set
 {     SET *set;
       AVLNODE *node;
       xassert(name != NULL);
-      node = avl_find_by_key(mpl->tree, name);
-      if (node == NULL || node->type != A_SET)
+      node = avl_find_node(mpl->tree, name);
+      if (node == NULL || avl_get_node_type(node) != A_SET)
          error(mpl, "%s not a set", name);
-      set = (SET *)node->link;
+      set = (SET *)avl_get_node_link(node);
       if (set->assign != NULL)
          error(mpl, "%s needs no data", name);
       set->data = 1;
@@ -643,10 +644,10 @@ PARAMETER *select_parameter
 {     PARAMETER *par;
       AVLNODE *node;
       xassert(name != NULL);
-      node = avl_find_by_key(mpl->tree, name);
-      if (node == NULL || node->type != A_PARAMETER)
+      node = avl_find_node(mpl->tree, name);
+      if (node == NULL || avl_get_node_type(node) != A_PARAMETER)
          error(mpl, "%s not a parameter", name);
-      par = (PARAMETER *)node->link;
+      par = (PARAMETER *)avl_get_node_link(node);
       if (par->assign != NULL)
          error(mpl, "%s needs no data", name);
       if (par->data)
