@@ -23,10 +23,10 @@
 -- 02110-1301, USA.
 ----------------------------------------------------------------------*/
 
-#include "glplib.h"
 #include "glpmpl.h"
 #define print xprint1
 #define fault xfault1
+#define dmp_create_poolx(size) dmp_create_pool()
 
 /**********************************************************************/
 /* * *              GENERATING AND POSTSOLVING MODEL              * * */
@@ -231,30 +231,30 @@ void clean_model(MPL *mpl)
       for (stmt = mpl->model; stmt != NULL; stmt = stmt->next)
          clean_statement(mpl, stmt);
       /* check that all atoms have been returned to their pools */
-      if (mpl->strings->count != 0)
+      if (dmp_in_use(mpl->strings).lo != 0)
          error(mpl, "internal logic error: %d string segment(s) were lo"
-            "st", mpl->strings->count);
-      if (mpl->symbols->count != 0)
+            "st", dmp_in_use(mpl->strings).lo);
+      if (dmp_in_use(mpl->symbols).lo != 0)
          error(mpl, "internal logic error: %d symbol(s) were lost",
-            mpl->symbols->count);
-      if (mpl->tuples->count != 0)
+            dmp_in_use(mpl->symbols).lo);
+      if (dmp_in_use(mpl->tuples).lo != 0)
          error(mpl, "internal logic error: %d n-tuple component(s) were"
-            " lost", mpl->tuples->count);
-      if (mpl->arrays->count != 0)
+            " lost", dmp_in_use(mpl->tuples).lo);
+      if (dmp_in_use(mpl->arrays).lo != 0)
          error(mpl, "internal logic error: %d array(s) were lost",
-            mpl->arrays->count);
-      if (mpl->members->count != 0)
+            dmp_in_use(mpl->arrays).lo);
+      if (dmp_in_use(mpl->members).lo != 0)
          error(mpl, "internal logic error: %d array member(s) were lost"
-            , mpl->members->count);
-      if (mpl->elemvars->count != 0)
+            , dmp_in_use(mpl->members).lo);
+      if (dmp_in_use(mpl->elemvars).lo != 0)
          error(mpl, "internal logic error: %d elemental variable(s) wer"
-            "e lost", mpl->elemvars->count);
-      if (mpl->formulae->count != 0)
+            "e lost", dmp_in_use(mpl->elemvars).lo);
+      if (dmp_in_use(mpl->formulae).lo != 0)
          error(mpl, "internal logic error: %d linear term(s) were lost",
-            mpl->formulae->count);
-      if (mpl->elemcons->count != 0)
+            dmp_in_use(mpl->formulae).lo);
+      if (dmp_in_use(mpl->elemcons).lo != 0)
          error(mpl, "internal logic error: %d elemental constraint(s) w"
-            "ere lost", mpl->elemcons->count);
+            "ere lost", dmp_in_use(mpl->elemcons).lo);
       return;
 }
 
@@ -535,8 +535,8 @@ MPL *mpl_initialize(void)
       mpl->c_ptr = 0;
       mpl->flag_d = 0;
       /* translating segment */
-      mpl->pool = dmp_create_pool(0);
-      mpl->tree = avl_create_tree(NULL, avl_strcmp);
+      mpl->pool = dmp_create_poolx(0);
+      mpl->tree = avl_create_tree(avl_strcmp, NULL);
       mpl->model = NULL;
       mpl->flag_x = 0;
       mpl->as_within = 0;
@@ -544,14 +544,14 @@ MPL *mpl_initialize(void)
       mpl->as_binary = 0;
       mpl->flag_s = 0;
       /* common segment */
-      mpl->strings = dmp_create_pool(sizeof(STRING));
-      mpl->symbols = dmp_create_pool(sizeof(SYMBOL));
-      mpl->tuples = dmp_create_pool(sizeof(TUPLE));
-      mpl->arrays = dmp_create_pool(sizeof(ARRAY));
-      mpl->members = dmp_create_pool(sizeof(MEMBER));
-      mpl->elemvars = dmp_create_pool(sizeof(ELEMVAR));
-      mpl->formulae = dmp_create_pool(sizeof(FORMULA));
-      mpl->elemcons = dmp_create_pool(sizeof(ELEMCON));
+      mpl->strings = dmp_create_poolx(sizeof(STRING));
+      mpl->symbols = dmp_create_poolx(sizeof(SYMBOL));
+      mpl->tuples = dmp_create_poolx(sizeof(TUPLE));
+      mpl->arrays = dmp_create_poolx(sizeof(ARRAY));
+      mpl->members = dmp_create_poolx(sizeof(MEMBER));
+      mpl->elemvars = dmp_create_poolx(sizeof(ELEMVAR));
+      mpl->formulae = dmp_create_poolx(sizeof(FORMULA));
+      mpl->elemcons = dmp_create_poolx(sizeof(ELEMCON));
       mpl->a_list = NULL;
       mpl->sym_buf = xcalloc(255+1, sizeof(char));
       mpl->sym_buf[0] = '\0';
