@@ -1,87 +1,89 @@
-/* glpqmd.c */
+/* glpqmd.c (quotient minimum degree algorithm) */
 
-/*----------------------------------------------------------------------
--- This code is part of GNU Linear Programming Kit (GLPK).
---
--- THIS CODE IS THE RESULT OF TRANSLATION OF THE FORTRAN SUBROUTINES
--- GENQMD, QMDRCH, QMDQT, QMDUPD, AND QMDMRG FROM THE BOOK:
---
--- ALAN GEORGE, JOSEPH W-H LIU. COMPUTER SOLUTION OF LARGE SPARSE
--- POSITIVE DEFINITE SYSTEMS. PRENTICE-HALL, 1981.
---
--- THE TRANSLATION HAS BEEN DONE WITH THE PERMISSION OF THE AUTHORS
--- OF THE ORIGINAL FORTRAN SUBROUTINES: ALAN GEORGE AND JOSEPH LIU,
--- UNIVERSITY OF WATERLOO, WATERLOO, ONTARIO, CANADA.
---
--- The translation was made by Andrew Makhorin <mao@mai2.rcnet.ru>.
---
--- GLPK is free software; you can redistribute it and/or modify it
--- under the terms of the GNU General Public License as published by
--- the Free Software Foundation; either version 2, or (at your option)
--- any later version.
---
--- GLPK is distributed in the hope that it will be useful, but WITHOUT
--- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
--- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
--- License for more details.
---
--- You should have received a copy of the GNU General Public License
--- along with GLPK; see the file COPYING. If not, write to the Free
--- Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
--- 02110-1301, USA.
-----------------------------------------------------------------------*/
+/***********************************************************************
+*  This code is part of GNU Linear Programming Kit (GLPK).
+* 
+*  THIS CODE IS THE RESULT OF TRANSLATION OF THE FORTRAN SUBROUTINES
+*  GENQMD, QMDRCH, QMDQT, QMDUPD, AND QMDMRG FROM THE BOOK:
+* 
+*  ALAN GEORGE, JOSEPH W-H LIU. COMPUTER SOLUTION OF LARGE SPARSE
+*  POSITIVE DEFINITE SYSTEMS. PRENTICE-HALL, 1981.
+* 
+*  THE TRANSLATION HAS BEEN DONE WITH THE PERMISSION OF THE AUTHORS
+*  OF THE ORIGINAL FORTRAN SUBROUTINES: ALAN GEORGE AND JOSEPH LIU,
+*  UNIVERSITY OF WATERLOO, WATERLOO, ONTARIO, CANADA.
+* 
+*  The translation was made by Andrew Makhorin <mao@mai2.rcnet.ru>.
+* 
+*  GLPK is free software; you can redistribute it and/or modify it
+*  under the terms of the GNU General Public License as published by
+*  the Free Software Foundation; either version 2, or (at your option)
+*  any later version.
+* 
+*  GLPK is distributed in the hope that it will be useful, but WITHOUT
+*  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+*  or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
+*  License for more details.
+* 
+*  You should have received a copy of the GNU General Public License
+*  along with GLPK; see the file COPYING. If not, write to the Free
+*  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+*  02110-1301, USA.
+***********************************************************************/
 
 #include "glpqmd.h"
 
-/*----------------------------------------------------------------------
--- genqmd - GENeral Quotient Minimum Degree algorithm.
---
--- *Synopsis*
---
--- #include "glpqmd.h"
--- void genqmd(int *neqns, int xadj[], int adjncy[], int perm[],
---    int invp[], int deg[], int marker[], int rchset[], int nbrhd[],
---    int qsize[], int qlink[], int *nofsub);
---
--- *Purpose*
---
--- This routine implements the minimum degree algorithm. It makes use
--- of the implicit representation of the elimination graph by quotient
--- graphs, and the notion of indistinguishable nodes.
---
--- *Caution*
---
--- The adjancy vector adjncy will be destroyed.
---
--- *Input parameters*
---
--- neqns  - number of equations;
--- (xadj, adjncy) -
---          the adjancy structure.
---
--- *Output parameters*
---
--- perm   - the minimum degree ordering;
--- invp   - the inverse of perm.
---
--- *Working parameters*
---
--- deg    - the degree vector. deg[i] is negative means node i has been
---          numbered;
--- marker - a marker vector, where marker[i] is negative means node i
---          has been merged with another nodeand thus can be ignored;
--- rchset - vector used for the reachable set;
--- nbrhd  - vector used for neighborhood set;
--- qsize  - vector used to store the size of indistinguishable
---          supernodes;
--- qlink  - vector used to store indistinguishable nodes, i, qlink[i],
---          qlink[qlink[i]], ... are the members of the supernode
---          represented by i.
---
--- *Program subroutines*
---
--- qmdrch, qmdqt, qmdupd.
-----------------------------------------------------------------------*/
+/***********************************************************************
+*  NAME
+*
+*  genqmd - GENeral Quotient Minimum Degree algorithm
+*
+*  SYNOPSIS
+*
+*  #include "glpqmd.h"
+*  void genqmd(int *neqns, int xadj[], int adjncy[], int perm[],
+*     int invp[], int deg[], int marker[], int rchset[], int nbrhd[],
+*     int qsize[], int qlink[], int *nofsub);
+*
+*  PURPOSE
+*
+*  This routine implements the minimum degree algorithm. It makes use
+*  of the implicit representation of the elimination graph by quotient
+*  graphs, and the notion of indistinguishable nodes.
+*
+*  CAUTION
+*
+*  The adjancy vector adjncy will be destroyed.
+*
+*  INPUT PARAMETERS
+*
+*  neqns  - number of equations;
+*  (xadj, adjncy) -
+*           the adjancy structure.
+*
+*  OUTPUT PARAMETERS
+*
+*  perm   - the minimum degree ordering;
+*  invp   - the inverse of perm.
+*
+*  WORKING PARAMETERS
+*
+*  deg    - the degree vector. deg[i] is negative means node i has been
+*           numbered;
+*  marker - a marker vector, where marker[i] is negative means node i
+*           has been merged with another nodeand thus can be ignored;
+*  rchset - vector used for the reachable set;
+*  nbrhd  - vector used for neighborhood set;
+*  qsize  - vector used to store the size of indistinguishable
+*           supernodes;
+*  qlink  - vector used to store indistinguishable nodes, i, qlink[i],
+*           qlink[qlink[i]], ... are the members of the supernode
+*           represented by i.
+*
+*  PROGRAM SUBROUTINES
+*
+*  qmdrch, qmdqt, qmdupd.
+***********************************************************************/
 
 void genqmd(int *_neqns, int xadj[], int adjncy[], int perm[],
       int invp[], int deg[], int marker[], int rchset[], int nbrhd[],
@@ -171,43 +173,45 @@ s600: num++;
 #     undef nofsub
 }
 
-/*----------------------------------------------------------------------
--- qmdrch - Quotient MD ReaCHable set.
---
--- *Synopsis*
---
--- #include "glpqmd.h"
--- void qmdrch(int *root, int xadj[], int adjncy[], int deg[],
---    int marker[], int *rchsze, int rchset[], int *nhdsze,
---    int nbrhd[]);
---
--- *Purpose*
---
--- This subroutine determines the reachable set of a node through a
--- given subset. The adjancy structure is assumed to be stored in a
--- quotient graph format.
---
--- *Input parameters*
---
--- root   - the given node not in the subset;
--- (xadj, adjncy) -
---          the adjancy structure pair;
--- deg    - the degree vector. deg[i] < 0 means the node belongs to the
---          given subset.
---
--- *Output parameters*
---
--- (rchsze, rchset) -
---          the reachable set;
--- (nhdsze, nbrhd) -
---          the neighborhood set.
---
--- *Updated parameters*
---
--- marker - the marker vector for reach and nbrhd sets. > 0 means the
---          node is in reach set. < 0 means the node has been merged
---          with others in the quotient or it is in nbrhd set.
-----------------------------------------------------------------------*/
+/***********************************************************************
+*  NAME
+*
+*  qmdrch - Quotient MD ReaCHable set
+*
+*  SYNOPSIS
+*
+*  #include "glpqmd.h"
+*  void qmdrch(int *root, int xadj[], int adjncy[], int deg[],
+*     int marker[], int *rchsze, int rchset[], int *nhdsze,
+*     int nbrhd[]);
+*
+*  PURPOSE
+*
+*  This subroutine determines the reachable set of a node through a
+*  given subset. The adjancy structure is assumed to be stored in a
+*  quotient graph format.
+* 
+*  INPUT PARAMETERS
+*
+*  root   - the given node not in the subset;
+*  (xadj, adjncy) -
+*           the adjancy structure pair;
+*  deg    - the degree vector. deg[i] < 0 means the node belongs to the
+*           given subset.
+*
+*  OUTPUT PARAMETERS
+*
+*  (rchsze, rchset) -
+*           the reachable set;
+*  (nhdsze, nbrhd) -
+*           the neighborhood set.
+*
+*  UPDATED PARAMETERS
+*
+*  marker - the marker vector for reach and nbrhd sets. > 0 means the
+*           node is in reach set. < 0 means the node has been merged
+*           with others in the quotient or it is in nbrhd set.
+***********************************************************************/
 
 void qmdrch(int *_root, int xadj[], int adjncy[], int deg[],
       int marker[], int *_rchsze, int rchset[], int *_nhdsze,
@@ -260,36 +264,38 @@ s600:    ;
 #     undef nhdsze
 }
 
-/*----------------------------------------------------------------------
--- qmdqt - Quotient MD Quotient graph Transformation.
---
--- *Synopsis*
---
--- #include "glpqmd.h"
--- void qmdqt(int *root, int xadj[], int adjncy[], int marker[],
---    int *rchsze, int rchset[], int nbrhd[]);
---
--- *Purpose*
---
--- This subroutine performs the quotient graph transformation after a
--- node has been eliminated.
---
--- *Input parameters*
---
--- root   - the node just eliminated. It becomes the representative of
---          the new supernode;
--- (xadj, adjncy) -
---          the adjancy structure;
--- (rchsze, rchset) -
---          the reachable set of root in the old quotient graph;
--- nbrhd  - the neighborhood set which will be merged with root to form
---          the new supernode;
--- marker - the marker vector.
---
--- *Updated parameter*
---
--- adjncy - becomes the adjncy of the quotient graph.
-----------------------------------------------------------------------*/
+/***********************************************************************
+*  NAME
+*
+*  qmdqt - Quotient MD Quotient graph Transformation
+*
+*  SYNOPSIS
+*
+*  #include "glpqmd.h"
+*  void qmdqt(int *root, int xadj[], int adjncy[], int marker[],
+*     int *rchsze, int rchset[], int nbrhd[]);
+*
+*  PURPOSE
+*
+*  This subroutine performs the quotient graph transformation after a
+*  node has been eliminated.
+*
+*  INPUT PARAMETERS
+*
+*  root   - the node just eliminated. It becomes the representative of
+*           the new supernode;
+*  (xadj, adjncy) -
+*           the adjancy structure;
+*  (rchsze, rchset) -
+*           the reachable set of root in the old quotient graph;
+*  nbrhd  - the neighborhood set which will be merged with root to form
+*           the new supernode;
+*  marker - the marker vector.
+*
+*  UPDATED PARAMETERS
+*
+*  adjncy - becomes the adjncy of the quotient graph.
+***********************************************************************/
 
 void qmdqt(int *_root, int xadj[], int adjncy[], int marker[],
       int *_rchsze, int rchset[], int nbrhd[])
@@ -342,44 +348,46 @@ s600:    ;
 #     undef rchsze
 }
 
-/*----------------------------------------------------------------------
--- qmdupd - Quotient MD UPDate.
---
--- *Synopsis*
---
--- #include "glpqmd.h"
--- void qmdupd(int xadj[], int adjncy[], int *nlist, int list[],
---    int deg[], int qsize[], int qlink[], int marker[], int rchset[],
---    int nbrhd[]);
---
--- *Purpose*
---
--- This routine performs degree update for a set of nodes in the minimum
--- degree algorithm.
---
--- *Input parameters*
---
--- (xadj, adjncy) -
---          the adjancy structure;
--- (nlist, list) -
---          the list of nodes whose degree has to be updated.
---
--- *Updated parameters*
---
--- deg    - the degree vector;
--- qsize  - size of indistinguishable supernodes;
--- qlink  - linked list for indistinguishable nodes;
--- marker - used to mark those nodes in reach/nbrhd sets.
---
--- *Working parameters*
---
--- rchset - the reachable set;
--- nbrhd  - the neighborhood set.
---
--- *Program subroutines*
---
--- qmdmrg.
-----------------------------------------------------------------------*/
+/***********************************************************************
+*  NAME
+*
+*  qmdupd - Quotient MD UPDate
+*
+*  SYNOPSIS
+*
+*  #include "glpqmd.h"
+*  void qmdupd(int xadj[], int adjncy[], int *nlist, int list[],
+*     int deg[], int qsize[], int qlink[], int marker[], int rchset[],
+*     int nbrhd[]);
+*
+*  PURPOSE
+*
+*  This routine performs degree update for a set of nodes in the minimum
+*  degree algorithm.
+*
+*  INPUT PARAMETERS
+*
+*  (xadj, adjncy) -
+*           the adjancy structure;
+*  (nlist, list) -
+*           the list of nodes whose degree has to be updated.
+*
+*  UPDATED PARAMETERS
+*
+*  deg    - the degree vector;
+*  qsize  - size of indistinguishable supernodes;
+*  qlink  - linked list for indistinguishable nodes;
+*  marker - used to mark those nodes in reach/nbrhd sets.
+*
+*  WORKING PARAMETERS
+*
+*  rchset - the reachable set;
+*  nbrhd  - the neighborhood set.
+*
+*  PROGRAM SUBROUTINES
+*
+*  qmdmrg.
+***********************************************************************/
 
 void qmdupd(int xadj[], int adjncy[], int *_nlist, int list[],
       int deg[], int qsize[], int qlink[], int marker[], int rchset[],
@@ -441,45 +449,47 @@ void qmdupd(int xadj[], int adjncy[], int *_nlist, int list[],
 #     undef nlist
 }
 
-/*----------------------------------------------------------------------
--- qmdmrg - Quotient MD MeRGe.
---
--- *Synopsis*
---
--- #include "qmdmrg.h"
--- void qmdmrg(int xadj[], int adjncy[], int deg[], int qsize[],
---    int qlink[], int marker[], int *deg0, int *nhdsze, int nbrhd[],
---    int rchset[], int ovrlp[]);
---
--- *Purpose*
---
--- This routine merges indistinguishable nodes in the minimum degree
--- ordering algorithm. It also computes the new degrees of these new
--- supernodes.
---
--- *Input parameters*
---
--- (xadj, adjncy) -
---          the adjancy structure;
--- deg0   - the number of nodes in the given set;
--- (nhdsze, nbrhd) -
---          the set of eliminated supernodes adjacent to some nodes in
---          the set.
---
--- *Updated parameters*
---
--- deg    - the degree vector;
--- qsize  - size of indistinguishable nodes;
--- qlink  - linked list for indistinguishable nodes;
--- marker - the given set is given by those nodes with marker value set
---          to 1. Those nodes with degree updated will have marker value
---          set to 2.
---
--- *Working parameters*
---
--- rchset - the reachable set;
--- ovrlp  - temp vector to store the intersection of two reachable sets.
-----------------------------------------------------------------------*/
+/***********************************************************************
+*  NAME
+*
+*  qmdmrg - Quotient MD MeRGe
+*
+*  SYNOPSIS
+*
+*  #include "qmdmrg.h"
+*  void qmdmrg(int xadj[], int adjncy[], int deg[], int qsize[],
+*     int qlink[], int marker[], int *deg0, int *nhdsze, int nbrhd[],
+*     int rchset[], int ovrlp[]);
+*
+*  PURPOSE
+*
+*  This routine merges indistinguishable nodes in the minimum degree
+*  ordering algorithm. It also computes the new degrees of these new
+*  supernodes.
+*
+*  INPUT PARAMETERS
+*
+*  (xadj, adjncy) -
+*           the adjancy structure;
+*  deg0   - the number of nodes in the given set;
+*  (nhdsze, nbrhd) -
+*           the set of eliminated supernodes adjacent to some nodes in
+*           the set.
+*
+*  UPDATED PARAMETERS
+*
+*  deg    - the degree vector;
+*  qsize  - size of indistinguishable nodes;
+*  qlink  - linked list for indistinguishable nodes;
+*  marker - the given set is given by those nodes with marker value set
+*           to 1. Those nodes with degree updated will have marker value
+*           set to 2.
+*
+*  WORKING PARAMETERS
+*
+*  rchset - the reachable set;
+*  ovrlp  - temp vector to store the intersection of two reachable sets.
+***********************************************************************/
 
 void qmdmrg(int xadj[], int adjncy[], int deg[], int qsize[],
       int qlink[], int marker[], int *_deg0, int *_nhdsze, int nbrhd[],
