@@ -89,7 +89,7 @@ static int inv_col(void *info, int j, int rn[], double bj[])
 int spx_invert(SPX *spx)
 {     int ret;
       /* try to factorize the basis matrix */
-      ret = bfi_factorize(spx->inv, spx->m, spx, inv_col);
+      ret = bfi_factorize(spx->inv, spx->m, inv_col, spx);
       /* analyze the return code */
       switch (ret)
       {  case 0:
@@ -147,7 +147,7 @@ int spx_invert(SPX *spx)
 
 void spx_ftran(SPX *spx, double x[], int save)
 {     xassert(spx->b_stat == LPX_B_VALID);
-      bfi_ftran_dense(spx->inv, x, save);
+      bfi_ftran(spx->inv, x, save);
       return;
 }
 
@@ -176,7 +176,7 @@ void spx_ftran(SPX *spx, double x[], int save)
 
 void spx_btran(SPX *spx, double x[])
 {     xassert(spx->b_stat == LPX_B_VALID);
-      bfi_btran_dense(spx->inv, x);
+      bfi_btran(spx->inv, x);
       return;
 }
 
