@@ -1,12 +1,12 @@
 /* glptsp.c */
 
 /*----------------------------------------------------------------------
--- Copyright (C) 2000, 2001, 2002, 2003, 2004 Andrew Makhorin,
+-- This code is part of GNU Linear Programming Kit (GLPK).
+--
+-- Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
 -- Department for Applied Informatics, Moscow Aviation Institute,
 -- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 --
--- This file is part of GLPK (GNU Linear Programming Kit).
---
 -- GLPK is free software; you can redistribute it and/or modify it
 -- under the terms of the GNU General Public License as published by
 -- the Free Software Foundation; either version 2, or (at your option)
@@ -19,18 +19,14 @@
 --
 -- You should have received a copy of the GNU General Public License
 -- along with GLPK; see the file COPYING. If not, write to the Free
--- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
--- 02111-1307, USA.
+-- Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+-- 02110-1301, USA.
 ----------------------------------------------------------------------*/
 
-#include <ctype.h>
-#include <errno.h>
-#include <float.h>
-#include <math.h>
-#include <stdio.h>
-#include <string.h>
 #include "glplib.h"
 #include "glptsp.h"
+#define print xprint1
+#define fault xfault1
 
 /*----------------------------------------------------------------------
 -- tsp_read_data - read TSP instance data.
@@ -188,7 +184,7 @@ static int scan_number(struct dsa *dsa, int across, double *val)
       {  print("%s:%d: missing number", dsa->fname, dsa->seqn);
          return 1;
       }
-      if (str2dbl(dsa->token, val))
+      if (str2num(dsa->token, val))
       {  print("%s:%d: number `%s' invalid", dsa->fname, dsa->seqn,
             dsa->token);
          return 1;
@@ -201,13 +197,13 @@ TSP *tsp_read_data(char *fname)
       TSP *tsp = NULL;
       dsa->fname = fname;
       print("tsp_read_data: reading TSP data from `%s'...", dsa->fname);
-      dsa->fp = ufopen(dsa->fname, "r");
+      dsa->fp = xfopen(dsa->fname, "r");
       if (dsa->fp == NULL)
       {  print("tsp_read_data: unable to open `%s' - %s", dsa->fname,
             strerror(errno));
          goto fail;
       }
-      tsp = umalloc(sizeof(TSP));
+      tsp = xmalloc(sizeof(TSP));
       tsp->name = NULL;
       tsp->type = TSP_UNDEF;
       tsp->comment = NULL;
@@ -237,7 +233,7 @@ loop: if (scan_keyword(dsa)) goto fail;
                dsa->seqn);
             goto fail;
          }
-         tsp->name = umalloc(strlen(dsa->token) + 1);
+         tsp->name = xmalloc(strlen(dsa->token) + 1);
          strcpy(tsp->name, dsa->token);
          print("tsp_read_data: NAME: %s", tsp->name);
          if (check_newline(dsa)) goto fail;
@@ -272,7 +268,7 @@ loop: if (scan_keyword(dsa)) goto fail;
          }
          if (check_colon(dsa)) goto fail;
          if (scan_comment(dsa)) goto fail;
-         tsp->comment = umalloc(strlen(dsa->token) + 1);
+         tsp->comment = xmalloc(strlen(dsa->token) + 1);
          strcpy(tsp->comment, dsa->token);
          print("tsp_read_data: COMMENT: %s", tsp->comment);
          if (check_newline(dsa)) goto fail;
@@ -375,8 +371,8 @@ loop: if (scan_keyword(dsa)) goto fail;
             goto fail;
          }
          if (check_newline(dsa)) goto fail;
-         tsp->node_x_coord = ucalloc(1+n, sizeof(double));
-         tsp->node_y_coord = ucalloc(1+n, sizeof(double));
+         tsp->node_x_coord = xcalloc(1+n, sizeof(double));
+         tsp->node_y_coord = xcalloc(1+n, sizeof(double));
          for (node = 1; node <= n; node++)
             tsp->node_x_coord[node] = tsp->node_y_coord[node] = DBL_MAX;
          for (k = 1; k <= n; k++)
@@ -411,8 +407,8 @@ loop: if (scan_keyword(dsa)) goto fail;
             goto fail;
          }
          if (check_newline(dsa)) goto fail;
-         tsp->dply_x_coord = ucalloc(1+n, sizeof(double));
-         tsp->dply_y_coord = ucalloc(1+n, sizeof(double));
+         tsp->dply_x_coord = xcalloc(1+n, sizeof(double));
+         tsp->dply_y_coord = xcalloc(1+n, sizeof(double));
          for (node = 1; node <= n; node++)
             tsp->dply_x_coord[node] = tsp->dply_y_coord[node] = DBL_MAX;
          for (k = 1; k <= n; k++)
@@ -447,7 +443,7 @@ loop: if (scan_keyword(dsa)) goto fail;
             goto fail;
          }
          if (check_newline(dsa)) goto fail;
-         tsp->tour = ucalloc(1+n, sizeof(int));
+         tsp->tour = xcalloc(1+n, sizeof(int));
          for (k = 1; k <= n; k++)
          {  if (scan_integer(dsa, 1, &node)) goto fail;
             if (!(1 <= node && node <= n))
@@ -483,7 +479,7 @@ loop: if (scan_keyword(dsa)) goto fail;
             goto fail;
          }
          if (check_newline(dsa)) goto fail;
-         tsp->edge_weight = ucalloc(1+n*n, sizeof(int));
+         tsp->edge_weight = xcalloc(1+n*n, sizeof(int));
          switch (tsp->edge_weight_format)
          {  case TSP_FULL_MATRIX:
                for (i = 1; i <= n; i++)
@@ -528,20 +524,20 @@ loop: if (scan_keyword(dsa)) goto fail;
       }
       goto loop;
 done: print("tsp_read_data: %d lines were read", dsa->seqn - 1);
-      ufclose(dsa->fp);
+      xfclose(dsa->fp);
       return tsp;
 fail: if (tsp != NULL)
-      {  if (tsp->name != NULL) ufree(tsp->name);
-         if (tsp->comment != NULL) ufree(tsp->comment);
-         if (tsp->node_x_coord != NULL) ufree(tsp->node_x_coord);
-         if (tsp->node_y_coord != NULL) ufree(tsp->node_y_coord);
-         if (tsp->dply_x_coord != NULL) ufree(tsp->dply_x_coord);
-         if (tsp->dply_y_coord != NULL) ufree(tsp->dply_y_coord);
-         if (tsp->tour != NULL) ufree(tsp->tour);
-         if (tsp->edge_weight != NULL) ufree(tsp->edge_weight);
-         ufree(tsp);
+      {  if (tsp->name != NULL) xfree(tsp->name);
+         if (tsp->comment != NULL) xfree(tsp->comment);
+         if (tsp->node_x_coord != NULL) xfree(tsp->node_x_coord);
+         if (tsp->node_y_coord != NULL) xfree(tsp->node_y_coord);
+         if (tsp->dply_x_coord != NULL) xfree(tsp->dply_x_coord);
+         if (tsp->dply_y_coord != NULL) xfree(tsp->dply_y_coord);
+         if (tsp->tour != NULL) xfree(tsp->tour);
+         if (tsp->edge_weight != NULL) xfree(tsp->edge_weight);
+         xfree(tsp);
       }
-      if (dsa->fp != NULL) ufclose(dsa->fp);
+      if (dsa->fp != NULL) xfclose(dsa->fp);
       return NULL;
 }
 
@@ -559,15 +555,15 @@ fail: if (tsp != NULL)
 -- instance data block, which the parameter tsp points to. */
 
 void tsp_free_data(TSP *tsp)
-{     if (tsp->name != NULL) ufree(tsp->name);
-      if (tsp->comment != NULL) ufree(tsp->comment);
-      if (tsp->node_x_coord != NULL) ufree(tsp->node_x_coord);
-      if (tsp->node_y_coord != NULL) ufree(tsp->node_y_coord);
-      if (tsp->dply_x_coord != NULL) ufree(tsp->dply_x_coord);
-      if (tsp->dply_y_coord != NULL) ufree(tsp->dply_y_coord);
-      if (tsp->tour != NULL) ufree(tsp->tour);
-      if (tsp->edge_weight != NULL) ufree(tsp->edge_weight);
-      ufree(tsp);
+{     if (tsp->name != NULL) xfree(tsp->name);
+      if (tsp->comment != NULL) xfree(tsp->comment);
+      if (tsp->node_x_coord != NULL) xfree(tsp->node_x_coord);
+      if (tsp->node_y_coord != NULL) xfree(tsp->node_y_coord);
+      if (tsp->dply_x_coord != NULL) xfree(tsp->dply_x_coord);
+      if (tsp->dply_y_coord != NULL) xfree(tsp->dply_y_coord);
+      if (tsp->tour != NULL) xfree(tsp->tour);
+      if (tsp->edge_weight != NULL) xfree(tsp->edge_weight);
+      xfree(tsp);
       return;
 }
 
@@ -658,7 +654,7 @@ int tsp_distance(TSP *tsp, int i, int j)
             }
             break;
          default:
-            insist(tsp->edge_weight_type != tsp->edge_weight_type);
+            xassert(tsp->edge_weight_type != tsp->edge_weight_type);
       }
       return dij;
 }
